@@ -1504,7 +1504,7 @@ DECLINLINE(int) VbglR0SfHostReqReadLinkContigSimple(SHFLROOT idRoot, const char
         {
             pReq->StrPath.u16Length = (uint16_t)cchPath;
             pReq->StrPath.u16Size   = (uint16_t)cchPath + 1;
-            memcpy(pReq->StrPath.String.ach, pszPath, cchPath);
+            RT_BCOPY_UNFORTIFIED(pReq->StrPath.String.ach, pszPath, cchPath);
             pReq->StrPath.String.ach[cchPath] = '\0';
 
             {
