@@ -3,46 +3,57 @@
  */
 
 /*
- * Copyright (C) 2006-2012 Oracle Corporation
+ * Copyright (C) 2006-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
  *
  * The contents of this file may alternatively be used under the terms
  * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
+ * (CDDL), a copy of it is provided in the "COPYING.CDDL" file included
+ * in the VirtualBox distribution, in which case the provisions of the
  * CDDL are applicable instead of those of the GPL.
  *
  * You may elect to license modified versions of this file under the
  * terms and conditions of either the GPL or the CDDL or both.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
  */
 
-#ifndef ___VBox_types_h
-#define ___VBox_types_h
+#ifndef VBOX_INCLUDED_types_h
+#define VBOX_INCLUDED_types_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include <VBox/cdefs.h>
 #include <iprt/types.h>
 
 
-/** @defgroup grp_types     Basic VBox Types
+/** @defgroup grp_types     VBox Basic Types
  * @{
  */
 
 
 /** @defgroup grp_types_both  Common Guest and Host Context Basic Types
- * @ingroup grp_types
  * @{
  */
 
 
 /** @defgroup grp_types_hc  Host Context Basic Types
- * @ingroup grp_types_both
  * @{
  */
 
@@ -50,7 +61,6 @@
 
 
 /** @defgroup grp_types_gc  Guest Context Basic Types
- * @ingroup grp_types_both
  * @{
  */
 
@@ -60,10 +70,30 @@
 /** Pointer to per support driver session data.
  * (The data is a R0 entity and private to the the R0 SUP part. All
  * other should consider this a sort of handle.) */
-typedef R0PTRTYPE(struct SUPDRVSESSION *) PSUPDRVSESSION;
+typedef R0PTRTYPE(struct SUPDRVSESSION *)           PSUPDRVSESSION;
+
+/** Event semaphore handle. Ring-0 / ring-3. */
+typedef R0PTRTYPE(struct SUPSEMEVENTHANDLE *)       SUPSEMEVENT;
+/** Pointer to an event semaphore handle. */
+typedef SUPSEMEVENT                                *PSUPSEMEVENT;
+/** Nil event semaphore handle. */
+#define NIL_SUPSEMEVENT                             ((SUPSEMEVENT)0)
+
+/** Multiple release event semaphore handle. Ring-0 / ring-3. */
+typedef R0PTRTYPE(struct SUPSEMEVENTMULTIHANDLE *)  SUPSEMEVENTMULTI;
+/** Pointer to an multiple release event semaphore handle. */
+typedef SUPSEMEVENTMULTI                           *PSUPSEMEVENTMULTI;
+/** Nil multiple release event semaphore handle. */
+#define NIL_SUPSEMEVENTMULTI                        ((SUPSEMEVENTMULTI)0)
+
+
+/** Pointer to a ring-3 VMM API vtable. */
+typedef R3PTRTYPE(const struct VMMR3VTABLE *) PCVMMR3VTABLE;
 
 /** Pointer to a VM. */
 typedef struct VM                  *PVM;
+/** Pointer to a const VM. */
+typedef const struct VM            *PCVM;
 /** Pointer to a VM - Ring-0 Ptr. */
 typedef R0PTRTYPE(struct VM *)      PVMR0;
 /** Pointer to a VM - Ring-3 Ptr. */
@@ -73,6 +103,8 @@ typedef RCPTRTYPE(struct VM *)      PVMRC;
 
 /** Pointer to a virtual CPU structure. */
 typedef struct VMCPU *              PVMCPU;
+/** Pointer to a const virtual CPU structure. */
+typedef const struct VMCPU *        PCVMCPU;
 /** Pointer to a virtual CPU structure - Ring-3 Ptr. */
 typedef R3PTRTYPE(struct VMCPU *)   PVMCPUR3;
 /** Pointer to a virtual CPU structure - Ring-0 Ptr. */
@@ -82,6 +114,12 @@ typedef RCPTRTYPE(struct VMCPU *)   PVMCPURC;
 
 /** Pointer to a ring-0 (global) VM structure. */
 typedef R0PTRTYPE(struct GVM *)     PGVM;
+/** Pointer to a const ring-0 (global) VM structure. */
+typedef R0PTRTYPE(const struct GVM *) PCGVM;
+/** Pointer to a GVMCPU structure. */
+typedef R0PTRTYPE(struct GVMCPU *)  PGVMCPU;
+/** Pointer to a const GVMCPU structure. */
+typedef R0PTRTYPE(struct GVMCPU const *) PCGVMCPU;
 
 /** Pointer to a ring-3 (user mode) VM structure. */
 typedef R3PTRTYPE(struct UVM *)     PUVM;
@@ -89,6 +127,35 @@ typedef R3PTRTYPE(struct UVM *)     PUVM;
 /** Pointer to a ring-3 (user mode) VMCPU structure. */
 typedef R3PTRTYPE(struct UVMCPU *)  PUVMCPU;
 
+/** Pointer to a context specific VM derived structure.
+ * This is PGVM in ring-0 and plain PVM in ring-3. */
+#ifdef IN_RING0
+typedef PGVM                        PVMCC;
+#else
+typedef PVM                         PVMCC;
+#endif
+/** Pointer to a const context specific VM derived structure.
+ * This is PCGVM in ring-0 and plain PCVM in ring-3. */
+#ifdef IN_RING0
+typedef PCGVM                       PCVMCC;
+#else
+typedef PCVM                        PCVMCC;
+#endif
+/** Pointer to a context specific VMCPUM derived structure.
+ * This is PGVMCPU in ring-0 and plain PVMCPU in ring-3. */
+#ifdef IN_RING0
+typedef PGVMCPU                     PVMCPUCC;
+#else
+typedef PVMCPU                      PVMCPUCC;
+#endif
+/** Pointer to a const context specific VMCPU derived structure.
+ * This is PCGVMCPU in ring-0 and plain PCVMCPU in ring-3. */
+#ifdef IN_RING0
+typedef PCGVMCPU                    PCVMCPUCC;
+#else
+typedef PCVMCPU                     PCVMCPUCC;
+#endif
+
 /** Virtual CPU ID. */
 typedef uint32_t                    VMCPUID;
 /** Pointer to a virtual CPU ID. */
@@ -150,6 +217,10 @@ typedef enum VMSTATE
     VMSTATE_RESETTING,
     /** Live save: The VM is being reset and immediately suspended. */
     VMSTATE_RESETTING_LS,
+    /** The VM is being soft/warm reset. */
+    VMSTATE_SOFT_RESETTING,
+    /** Live save: The VM is being soft/warm reset (not suspended afterwards). */
+    VMSTATE_SOFT_RESETTING_LS,
     /** The VM is being suspended. */
     VMSTATE_SUSPENDING,
     /** Live save: The VM is being suspended during a live save operation, either as
@@ -207,9 +278,6 @@ typedef enum VMSTATE
       || defined(DEBUG) \
       || defined(DOXYGEN_RUNNING) )
 # define VBOXSTRICTRC_STRICT_ENABLED 1
-# ifdef _MSC_VER
-#  pragma warning(disable:4190)
-# endif
 #endif
 
 /** We need RTERR_STRICT_RC.  */
@@ -285,6 +353,9 @@ private:
     VBOXSTRICTRC(int64_t rc)  : m_rc(-999)          { NOREF(rc); }
     /** @} */
 };
+# ifdef _MSC_VER
+#  pragma warning(disable:4190)
+# endif
 #else
 typedef int32_t VBOXSTRICTRC;
 #endif
@@ -306,21 +377,53 @@ typedef int32_t VBOXSTRICTRC;
 #define VBOXSTRICTRC_TODO(rcStrict) VBOXSTRICTRC_VAL(rcStrict)
 
 
+/** A cross context I/O port range handle. */
+typedef uint64_t                IOMIOPORTHANDLE;
+/** Pointer to a cross context I/O port handle. */
+typedef IOMIOPORTHANDLE        *PIOMIOPORTHANDLE;
+/** A NIL I/O port handle. */
+#define NIL_IOMIOPORTHANDLE     ((uint64_t)UINT64_MAX)
+
+/** A cross context MMIO range handle. */
+typedef uint64_t                IOMMMIOHANDLE;
+/** Pointer to a cross context MMIO handle. */
+typedef IOMMMIOHANDLE          *PIOMMMIOHANDLE;
+/** A NIL MMIO handle. */
+#define NIL_IOMMMIOHANDLE       ((uint64_t)UINT64_MAX)
+
+/** A cross context MMIO2 range handle. */
+typedef uint64_t                PGMMMIO2HANDLE;
+/** Pointer to a cross context MMIO2 handle. */
+typedef PGMMMIO2HANDLE         *PPGMMMIO2HANDLE;
+/** A NIL MMIO2 handle. */
+#define NIL_PGMMMIO2HANDLE      ((uint64_t)UINT64_MAX)
+
 /** Pointer to a PDM Base Interface. */
 typedef struct PDMIBASE *PPDMIBASE;
 /** Pointer to a pointer to a PDM Base Interface. */
 typedef PPDMIBASE *PPPDMIBASE;
 
-/** Pointer to a PDM Device Instance. */
-typedef struct PDMDEVINS *PPDMDEVINS;
-/** Pointer to a pointer to a PDM Device Instance. */
+/** Pointer to a PDM device instance for the current context. */
+#ifdef IN_RING3
+typedef struct PDMDEVINSR3 *PPDMDEVINS;
+#elif defined(IN_RING0) || defined(DOXYGEN_RUNNING)
+typedef struct PDMDEVINSR0 *PPDMDEVINS;
+#else
+typedef struct PDMDEVINSRC *PPDMDEVINS;
+#endif
+/** Pointer to a pointer a PDM device instance for the current context. */
 typedef PPDMDEVINS *PPPDMDEVINS;
-/** R3 pointer to a PDM Device Instance. */
-typedef R3PTRTYPE(PPDMDEVINS) PPDMDEVINSR3;
-/** R0 pointer to a PDM Device Instance. */
-typedef R0PTRTYPE(PPDMDEVINS) PPDMDEVINSR0;
-/** RC pointer to a PDM Device Instance. */
-typedef RCPTRTYPE(PPDMDEVINS) PPDMDEVINSRC;
+/** R3 pointer to a PDM device instance. */
+typedef R3PTRTYPE(struct PDMDEVINSR3 *) PPDMDEVINSR3;
+/** R0 pointer to a PDM device instance. */
+typedef R0PTRTYPE(struct PDMDEVINSR0 *) PPDMDEVINSR0;
+/** RC pointer to a PDM device instance. */
+typedef RCPTRTYPE(struct PDMDEVINSRC *) PPDMDEVINSRC;
+
+/** Pointer to a PDM PCI device structure. */
+typedef struct PDMPCIDEV *PPDMPCIDEV;
+/** Pointer to a const PDM PCI device structure. */
+typedef const struct PDMPCIDEV *PCPDMPCIDEV;
 
 /** Pointer to a PDM USB Device Instance. */
 typedef struct PDMUSBINS *PPDMUSBINS;
@@ -348,6 +451,18 @@ typedef union PDMCRITSECT *PPDMCRITSECT;
 /** Pointer to a const PDM critical section. */
 typedef const union PDMCRITSECT *PCPDMCRITSECT;
 
+/** Pointer to a PDM read/write critical section. */
+typedef union PDMCRITSECTRW *PPDMCRITSECTRW;
+/** Pointer to a const PDM read/write critical section. */
+typedef union PDMCRITSECTRW const *PCPDMCRITSECTRW;
+
+/** PDM queue handle. */
+typedef uint64_t PDMQUEUEHANDLE;
+/** Pointer to a PDM queue handle. */
+typedef PDMQUEUEHANDLE *PPDMQUEUEHANDLE;
+/** NIL PDM queue handle. */
+#define NIL_PDMQUEUEHANDLE ((PDMQUEUEHANDLE)UINT64_MAX)
+
 /** R3 pointer to a timer. */
 typedef R3PTRTYPE(struct TMTIMER *) PTMTIMERR3;
 /** Pointer to a R3 pointer to a timer. */
@@ -364,9 +479,16 @@ typedef RCPTRTYPE(struct TMTIMER *) PTMTIMERRC;
 typedef PTMTIMERRC *PPTMTIMERRC;
 
 /** Pointer to a timer. */
-typedef CTX_SUFF(PTMTIMER)     PTMTIMER;
+typedef CTX_SUFF(PTMTIMER) PTMTIMER;
 /** Pointer to a pointer to a timer. */
-typedef PTMTIMER              *PPTMTIMER;
+typedef PTMTIMER *PPTMTIMER;
+
+/** A cross context timer handle. */
+typedef uint64_t TMTIMERHANDLE;
+/** Pointer to a cross context timer handle. */
+typedef TMTIMERHANDLE *PTMTIMERHANDLE;
+/** A NIL timer handle. */
+#define NIL_TMTIMERHANDLE ((uint64_t)UINT64_MAX)
 
 /** SSM Operation handle. */
 typedef struct SSMHANDLE *PSSMHANDLE;
@@ -378,11 +500,6 @@ typedef struct CPUMCTX *PCPUMCTX;
 /** Pointer to a const CPUMCTX. */
 typedef const struct CPUMCTX *PCCPUMCTX;
 
-/** Pointer to a CPU context core. */
-typedef struct CPUMCTXCORE *PCPUMCTXCORE;
-/** Pointer to a const CPU context core. */
-typedef const struct CPUMCTXCORE *PCCPUMCTXCORE;
-
 /** Pointer to a selector register. */
 typedef struct CPUMSELREG *PCPUMSELREG;
 /** Pointer to a const selector register. */
@@ -395,11 +512,52 @@ typedef struct CPUMSELREG *PCPUMSELREGHID;
  * @deprecated Replaced by PCCPUMSELREG  */
 typedef const struct CPUMSELREG *PCCPUMSELREGHID;
 
+/** A cross context DBGF tracer event source handle. */
+typedef uint64_t                DBGFTRACEREVTSRC;
+/** Pointer to a cross context DBGF tracer event source handle. */
+typedef DBGFTRACEREVTSRC        *PDBGFTRACEREVTSRC;
+/** A NIL DBGF tracer event source handle. */
+#define NIL_DBGFTRACEREVTSRC    ((uint64_t)UINT64_MAX)
+
+/** Pointer to a DBGF tracer instance for the current context. */
+#ifdef IN_RING3
+typedef struct DBGFTRACERINSR3 *PDBGFTRACERINSCC;
+#elif defined(IN_RING0) || defined(DOXYGEN_RUNNING)
+typedef struct DBGFTRACERINSR0 *PDBGFTRACERINSCC;
+#else
+typedef struct DBGFTRACERINSRC *PDBGFTRACERINSCC;
+#endif
+/** Pointer to a pointer a DBGF tracer instance for the current context. */
+typedef PDBGFTRACERINSCC *PPDBGFTRACERINSCC;
+/** R3 pointer to a DBGF tracer instance. */
+typedef R3PTRTYPE(struct DBGFTRACERINSR3 *) PDBGFTRACERINSR3;
+/** R0 pointer to a DBGF tracer instance. */
+typedef R0PTRTYPE(struct DBGFTRACERINSR0 *) PDBGFTRACERINSR0;
+/** RC pointer to a DBGF tracer instance. */
+typedef RCPTRTYPE(struct DBGFTRACERINSRC *) PDBGFTRACERINSRC;
+
+/** A cross context DBGF breakpoint owner handle. */
+typedef uint32_t                DBGFBPOWNER;
+/** Pointer to a cross context DBGF breakpoint owner handle. */
+typedef DBGFBPOWNER            *PDBGFBPOWNER;
+/** A NIL DBGF breakpoint owner handle. */
+#define NIL_DBGFBPOWNER         ((uint32_t)UINT32_MAX)
+
+/** A cross context DBGF breakpoint handle. */
+typedef uint32_t                DBGFBP;
+/** Pointer to a cross context DBGF breakpoint handle. */
+typedef DBGFBP                 *PDBGFBP;
+/** A NIL DBGF breakpoint handle. */
+#define NIL_DBGFBP              ((uint32_t)UINT32_MAX)
+
+/** A sample report handle. */
+typedef struct DBGFSAMPLEREPORTINT *DBGFSAMPLEREPORT;
+/** Pointer to a sample report handle. */
+typedef DBGFSAMPLEREPORT       *PDBGFSAMPLEREPORT;
 /** @} */
 
 
 /** @defgroup grp_types_idt     Interrupt Descriptor Table Entry.
- * @ingroup grp_types
  * @todo This all belongs in x86.h!
  * @{ */
 
@@ -737,8 +895,6 @@ typedef struct VBOXIDTR
 } VBOXIDTR, *PVBOXIDTR;
 #pragma pack()
 
-/** @} */
-
 
 /** @def VBOXIDTE_OFFSET
  * Return the offset of an IDT entry.
@@ -913,6 +1069,8 @@ typedef enum PDMNETWORKGSOTYPE
  *
  * @remarks This is part of the internal network GSO packets.  Take great care
  *          when making changes.  The size is expected to be exactly 8 bytes.
+ *
+ * @ingroup grp_pdm
  */
 typedef struct PDMNETWORKGSO
 {
@@ -932,16 +1090,26 @@ typedef struct PDMNETWORKGSO
     /** Unused. */
     uint8_t             u8Unused;
 } PDMNETWORKGSO;
-/** Pointer to a GSO context. */
+/** Pointer to a GSO context.
+ * @ingroup grp_pdm */
 typedef PDMNETWORKGSO *PPDMNETWORKGSO;
-/** Pointer to a const GSO context. */
+/** Pointer to a const GSO context.
+ * @ingroup grp_pdm */
 typedef PDMNETWORKGSO const *PCPDMNETWORKGSO;
 
+/** Pointer to a PDM filter handle.
+ * @ingroup grp_pdm_net_shaper  */
+typedef struct PDMNSFILTER *PPDMNSFILTER;
+/** Pointer to a network shaper.
+ * @ingroup grp_pdm_net_shaper */
+typedef struct PDMNETSHAPER *PPDMNETSHAPER;
+
 
 /**
  * The current ROM page protection.
  *
  * @remarks This is part of the saved state.
+ * @ingroup grp_pgm
  */
 typedef enum PGMROMPROT
 {
@@ -968,10 +1136,11 @@ typedef enum PGMROMPROT
 
 /**
  * Page mapping lock.
+ * @ingroup grp_pgm
  */
 typedef struct PGMPAGEMAPLOCK
 {
-#if defined(IN_RC) || defined(VBOX_WITH_2X_4GB_ADDR_SPACE_IN_R0)
+#if defined(IN_RC)
     /** The locked page. */
     void       *pvPage;
     /** Pointer to the CPU that made the mapping.
@@ -992,7 +1161,8 @@ typedef struct PGMPAGEMAPLOCK
     void       *pvMap;
 #endif
 } PGMPAGEMAPLOCK;
-/** Pointer to a page mapping lock. */
+/** Pointer to a page mapping lock.
+ * @ingroup grp_pgm */
 typedef PGMPAGEMAPLOCK *PPGMPAGEMAPLOCK;
 
 
@@ -1052,6 +1222,37 @@ typedef PDISSTATE PDISCPUSTATE;
 typedef PCDISSTATE PCDISCPUSTATE;
 
 
+/**
+ * Shared region description (needed by GMM and others, thus global).
+ * @ingroup grp_vmmdev
+ */
+typedef struct VMMDEVSHAREDREGIONDESC
+{
+    RTGCPTR64           GCRegionAddr;
+    uint32_t            cbRegion;
+    uint32_t            u32Alignment;
+} VMMDEVSHAREDREGIONDESC;
+
+
+/**
+ * A PCI bus:device:function (BDF) identifier.
+ *
+ * All 16 bits of a BDF are valid according to the PCI spec. We need one extra bit
+ * to determine whether the BDF is valid in interfaces where the BDF may be
+ * optional.
+ */
+typedef uint32_t PCIBDF;
+/** PCIBDF flag: Invalid. */
+#define PCI_BDF_F_INVALID           RT_BIT(31)
+/** Nil PCIBDF value. */
+#define NIL_PCIBDF                  PCI_BDF_F_INVALID
+
+/** Pointer to an MSI message struct. */
+typedef struct MSIMSG *PMSIMSG;
+/** Pointer to a const MSI message struct. */
+typedef const struct MSIMSG *PCMSIMSG;
+
+
 /** @} */
 
-#endif
+#endif /* !VBOX_INCLUDED_types_h */
