@@ -5,7 +5,7 @@
  */
 
 /*
- * Copyright (C) 2015-2022 Oracle and/or its affiliates.
+ * Copyright (C) 2015-2023 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -42,8 +42,13 @@
 #include <iprt/file.h>
 #include <iprt/string.h>
 #include <iprt/process.h>
+#include <iprt/thread.h>
+#include <iprt/err.h>
 #include "VBoxGuestR3LibInternal.h"
 
+/* A time to wait before starting the next attempt to check a pidfile. */
+#define VBGL_PIDFILE_WAIT_RELAX_TIME_MS (250)
+
 /**
  * Creates a PID File and returns the open file descriptor.
  *
@@ -116,3 +121,31 @@ VBGLR3DECL(void) VbglR3ClosePidFile(const char *pszPath, RTFILE hFile)
     }
 }
 
+
+/**
+ * Wait for other process to release pidfile.
+ *
+ * This function is a wrapper to VbglR3PidFile().
+ *
+ * @returns IPRT status code.
+ * @param   szPidfile       Path to pidfile.
+ * @param   phPidfile       Handle to pidfile.
+ * @param   u64TimeoutMs    A timeout value in milliseconds to wait for
+ *                          other process to release pidfile.
+ */
+VBGLR3DECL(int) VbglR3PidfileWait(const char *szPidfile, RTFILE *phPidfile, uint64_t u64TimeoutMs)
+{
+    int rc = VERR_FILE_LOCK_VIOLATION;
+    uint64_t u64Start = RTTimeSystemMilliTS();
+
+    AssertPtrReturn(szPidfile, VERR_INVALID_PARAMETER);
+    AssertPtrReturn(phPidfile, VERR_INVALID_PARAMETER);
+
+    while (   !RT_SUCCESS((rc = VbglR3PidFile(szPidfile, phPidfile)))
+           && (RTTimeSystemMilliTS() - u64Start < u64TimeoutMs))
+    {
+        RTThreadSleep(VBGL_PIDFILE_WAIT_RELAX_TIME_MS);
+    }
+
+    return rc;
+}
