@@ -63,6 +63,7 @@
 #elif RTLNX_VER_MIN(2,6,0)
 # include <linux/parser.h>
 #endif
+#include <VBox/VBoxLnxModInline.h>
 
 
 /*********************************************************************************************************************************
@@ -118,7 +119,7 @@ static void vbsf_super_info_copy_remount_options(struct vbsf_super_info *pSuperI
 
     if ((unsigned)info->length >= RT_UOFFSETOF(struct vbsf_mount_info_new, cMaxIoPages)) {
         AssertCompile(sizeof(pSuperInfo->szTag) >= sizeof(info->szTag));
-        VBSF_UNFORTIFIED_MEMCPY(pSuperInfo->szTag, info->szTag, sizeof(info->szTag));
+        RT_BCOPY_UNFORTIFIED(pSuperInfo->szTag, info->szTag, sizeof(info->szTag));
         pSuperInfo->szTag[sizeof(pSuperInfo->szTag) - 1] = '\0';
     } else {
         pSuperInfo->szTag[0] = '\0';
@@ -242,7 +243,7 @@ static int vbsf_super_info_alloc_and_map_it(struct vbsf_mount_info_new *info, st
 
         str_name->u16Length = name_len;
         str_name->u16Size = name_len + 1;
-        VBSF_UNFORTIFIED_MEMCPY(str_name->String.utf8, info->name, name_len + 1);
+        RT_BCOPY_UNFORTIFIED(str_name->String.utf8, info->name, name_len + 1);
 
         /*
          * Init the NLS support, if needed.
@@ -1408,7 +1409,7 @@ static int vbsf_parse_param(struct fs_context *fc, struct fs_parameter *param)
     switch (opt) {
     case Opt_iocharset:
     case Opt_nls:
-        strlcpy(info->nls_name, param->string, sizeof(info->nls_name));
+        RTStrCopy(info->nls_name, sizeof(info->nls_name), param->string);
         break;
     case Opt_uid:
         info->uid = result.uint_32;
@@ -1469,7 +1470,7 @@ static int vbsf_parse_param(struct fs_context *fc, struct fs_parameter *param)
             printk(KERN_WARNING "vboxsf: cache mode (%u) is out of range, using default instead.\n", result.uint_32);
         break;
     case Opt_tag:
-        strlcpy(info->szTag, param->string, sizeof(info->szTag));
+        RTStrCopy(info->szTag, sizeof(info->szTag), param->string);
         break;
     default:
         return invalf(fc, "Invalid mount option: '%s'", param->key);
@@ -1489,7 +1490,7 @@ static int vbsf_parse_monolithic(struct fs_context *fc, void *data)
 
     if (data) {
         if (VBSF_IS_MOUNT_VBOXSF_DATA(data)) {
-            VBSF_UNFORTIFIED_MEMCPY(info, data, sizeof(struct vbsf_mount_info_new));
+            RT_BCOPY_UNFORTIFIED(info, data, sizeof(struct vbsf_mount_info_new));
         } else {
             /* this will call vbsf_parse_param() */
             return generic_parse_monolithic(fc, data);
@@ -1528,7 +1529,7 @@ static int vbsf_get_tree(struct fs_context *fc)
     }
 
     /* fc->source (the shared folder name) is set after vbsf_init_fs_ctx() */
-    strlcpy(info->name, fc->source, sizeof(info->name));
+    RTStrCopy(info->name, sizeof(info->name), fc->source);
 
 # if RTLNX_VER_MAX(5,3,0)
     return vfs_get_super(fc, vfs_get_independent_super, vbsf_read_super_aux);
@@ -1621,6 +1622,10 @@ static int __init init(void)
     int rc;
     SFLOGFLOW(("vboxsf: init\n"));
 
+    /* Check if modue loading was disabled. */
+    if (!vbox_mod_should_load())
+        return -EINVAL;
+
     /*
      * Must be paranoid about the vbsf_mount_info_new size.
      */
