@@ -37,10 +37,14 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #include "StringFuncs.h"
 #include "ParseInf.h"
 #include "PeCoffLib.h"
+
+#ifdef VBOX
+# include <iprt/cdefs.h>
+#endif
 /*
 
 #ifdef __GNUC__
-//#pragma GCC diagnostic ignored "-Wimplicit-fallthrough"
+#pragma GCC diagnostic ignored "-Wimplicit-fallthrough"
 #endif
 */
 //
@@ -1082,7 +1086,7 @@ Returns:
   }
 
   if (VolumeHeader.FvLength != Size) {
-    printf ("ERROR: Volume Size not consistant with Block Maps!\n");
+    printf ("ERROR: Volume Size not consistent with Block Maps!\n");
     return EFI_ABORTED;
   }
 
@@ -1195,10 +1199,14 @@ Returns:
 
   case EFI_FILE_DELETED:
     printf ("        EFI_FILE_DELETED\n");
-
+#ifdef VBOX
+    RT_FALL_THRU();
+#endif
   case EFI_FILE_MARKED_FOR_UPDATE:
     printf ("        EFI_FILE_MARKED_FOR_UPDATE\n");
-
+#ifdef VBOX
+    RT_FALL_THRU();
+#endif
   case EFI_FILE_DATA_VALID:
     printf ("        EFI_FILE_DATA_VALID\n");
 
