@@ -78,7 +78,7 @@ HttpCreateService (
   @param[in]  HttpService        The HTTP private instance.
   @param[in]  UsingIpv6          Indicate use TCP4 protocol or TCP6 protocol.
                                  if TRUE, use Tcp6 protocol.
-                                 if FALSE, use Tcp4 protocl.
+                                 if FALSE, use Tcp4 protocol.
 **/
 VOID
 HttpCleanService (
@@ -152,7 +152,7 @@ HttpUtilitiesInstalledCallback (
          );
 
   //
-  // Close the event if Http utilities protocol is loacted.
+  // Close the event if Http utilities protocol is located.
   //
   if (mHttpUtilities != NULL && Event != NULL) {
      gBS->CloseEvent (Event);
@@ -668,7 +668,7 @@ HttpDxeIp4DriverBindingSupported (
   @retval EFI_ALREADY_STARTED      This device is already running on ControllerHandle.
   @retval EFI_DEVICE_ERROR         The device could not be started due to a device error.Currently not implemented.
   @retval EFI_OUT_OF_RESOURCES     The request could not be completed due to a lack of resources.
-  @retval Others                   The driver failded to start the device.
+  @retval Others                   The driver failed to start the device.
 
 **/
 EFI_STATUS
@@ -823,7 +823,7 @@ HttpDxeIp6DriverBindingSupported (
   @retval EFI_ALREADY_STARTED      This device is already running on ControllerHandle.
   @retval EFI_DEVICE_ERROR         The device could not be started due to a device error.Currently not implemented.
   @retval EFI_OUT_OF_RESOURCES     The request could not be completed due to a lack of resources.
-  @retval Others                   The driver failded to start the device.
+  @retval Others                   The driver failed to start the device.
 
 **/
 EFI_STATUS
@@ -897,7 +897,7 @@ HttpDxeIp6DriverBindingStop (
                       then a new handle is created. If it is a pointer to an existing UEFI handle,
                       then the protocol is added to the existing UEFI handle.
 
-  @retval EFI_SUCCES            The protocol was added to ChildHandle.
+  @retval EFI_SUCCESS           The protocol was added to ChildHandle.
   @retval EFI_INVALID_PARAMETER This is NULL, or ChildHandle is NULL.
   @retval EFI_OUT_OF_RESOURCES  There are not enough resources available to create
                                 the child.
@@ -981,7 +981,7 @@ ON_ERROR:
   @param  This        Pointer to the EFI_SERVICE_BINDING_PROTOCOL instance.
   @param  ChildHandle Handle of the child to destroy
 
-  @retval EFI_SUCCES            The protocol was removed from ChildHandle.
+  @retval EFI_SUCCESS           The protocol was removed from ChildHandle.
   @retval EFI_UNSUPPORTED       ChildHandle does not support the protocol that is being removed.
   @retval EFI_INVALID_PARAMETER Child handle is NULL.
   @retval other                 The child handle was not destroyed
