@@ -1,15 +1,9 @@
 /** @file
   Mtftp6 internal data structure and definition declaration.
 
-  Copyright (c) 2009 - 2011, Intel Corporation. All rights reserved. <BR>
+  Copyright (c) 2009 - 2018, Intel Corporation. All rights reserved. <BR>
 
-  This program and the accompanying materials
-  are licensed and made available under the terms and conditions of the BSD License
-  which accompanies this distribution.  The full text of the license may be found at
-  http://opensource.org/licenses/bsd-license.php.
-
-  THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
-  WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
+  SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
@@ -29,6 +23,7 @@
 #include <Library/UefiLib.h>
 #include <Library/BaseLib.h>
 #include <Library/NetLib.h>
+#include <Library/PrintLib.h>
 
 typedef struct _MTFTP6_SERVICE  MTFTP6_SERVICE;
 typedef struct _MTFTP6_INSTANCE MTFTP6_INSTANCE;
@@ -45,6 +40,7 @@ typedef struct _MTFTP6_INSTANCE MTFTP6_INSTANCE;
 #define MTFTP6_GET_MAPPING_TIMEOUT     3
 #define MTFTP6_DEFAULT_MAX_RETRY       5
 #define MTFTP6_DEFAULT_BLK_SIZE        512
+#define MTFTP6_DEFAULT_WINDOWSIZE      1
 #define MTFTP6_TICK_PER_SECOND         10000000U
 
 #define MTFTP6_SERVICE_FROM_THIS(a)    CR (a, MTFTP6_SERVICE, ServiceBinding, MTFTP6_SERVICE_SIGNATURE)
@@ -76,6 +72,20 @@ struct _MTFTP6_INSTANCE {
   UINT16                        LastBlk;
   LIST_ENTRY                    BlkList;
 
+  UINT16                        Operation;
+
+  UINT16                        WindowSize;
+
+  //
+  // Record the total received and saved block number.
+  //
+  UINT64                        TotalBlock;
+
+  //
+  // Record the acked block number.
+  //
+  UINT64                        AckedBlock;
+
   EFI_IPv6_ADDRESS              ServerIp;
   UINT16                        ServerCmdPort;
   UINT16                        ServerDataPort;
@@ -94,7 +104,7 @@ struct _MTFTP6_INSTANCE {
   EFI_TPL                       OldTpl;
   BOOLEAN                       IsTransmitted;
   BOOLEAN                       IsMaster;
-  BOOLEAN                       InDestory;
+  BOOLEAN                       InDestroy;
 };
 
 //
@@ -117,9 +127,14 @@ struct _MTFTP6_SERVICE {
   // mtftp driver and udp driver.
   //
   UDP_IO                        *DummyUdpIo;
-  BOOLEAN                       InDestory;
 };
 
+typedef struct {
+  EFI_SERVICE_BINDING_PROTOCOL  *ServiceBinding;
+  UINTN                         NumberOfChildren;
+  EFI_HANDLE                    *ChildHandleBuffer;
+} MTFTP6_DESTROY_CHILD_IN_HANDLE_BUF_CONTEXT;
+
 /**
   Returns the current operating mode data for the MTFTP6 instance.
 
@@ -164,11 +179,11 @@ EfiMtftp6GetModeData (
                                  - This is NULL.
                                  - MtftpConfigData.StationIp is neither zero nor one
                                    of the configured IP addresses in the underlying IPv6 driver.
-                                 - MtftpCofigData.ServerIp is not a valid IPv6 unicast address.
+                                 - MtftpConfigData.ServerIp is not a valid IPv6 unicast address.
                                  Note: It does not match the UEFI 2.3 Specification.
   @retval  EFI_ACCESS_DENIED     - The configuration could not be changed at this time because there
                                    is some MTFTP background operation in progress.
-                                 - MtftpCofigData.LocalPort is already in use.
+                                 - MtftpConfigData.LocalPort is already in use.
                                  Note: It does not match the UEFI 2.3 Specification.
   @retval  EFI_NO_MAPPING        The underlying IPv6 driver was responsible for choosing a source
                                  address for this instance, but no source address was available for use.
