@@ -43,7 +43,7 @@ CreatePopulateInstallShellParametersProtocol (
   );
 
 /**
-  frees all memory used by createion and installation of shell parameters protocol
+  frees all memory used by creation and installation of shell parameters protocol
   and if there was an old version installed it will restore that one.
 
   @param NewShellParameters the interface of EFI_SHELL_PARAMETERS_PROTOCOL that is
@@ -60,7 +60,7 @@ CleanUpShellParametersProtocol (
   );
 
 /**
-  Funcion will replace the current Argc and Argv in the ShellParameters protocol
+  Function will replace the current Argc and Argv in the ShellParameters protocol
   structure by parsing NewCommandLine.  The current values are returned to the
   user.
 
@@ -70,7 +70,8 @@ CleanUpShellParametersProtocol (
   @param[out] OldArgv                   pointer to old list of parameters
   @param[out] OldArgc                   pointer to old number of items in Argv list
 
-  @retval   EFI_SUCCESS                 operation was sucessful, Argv and Argc are valid
+  @retval   EFI_SUCCESS                 operation was successful, Argv and Argc are valid
+  @return   EFI_INVALID_PARAMETER       some parameters are invalid
   @retval   EFI_OUT_OF_RESOURCES        a memory allocation failed.
 **/
 EFI_STATUS
@@ -83,7 +84,7 @@ UpdateArgcArgv(
   );
 
 /**
-  Funcion will replace the current Argc and Argv in the ShellParameters protocol
+  Function will replace the current Argc and Argv in the ShellParameters protocol
   structure with Argv and Argc.  The current values are de-allocated and the
   OldArgv must not be deallocated by the caller.
 
@@ -108,7 +109,7 @@ typedef struct {
 } SYSTEM_TABLE_INFO;
 
 /**
-  Funcion will replace the current StdIn and StdOut in the ShellParameters protocol
+  Function will replace the current StdIn and StdOut in the ShellParameters protocol
   structure by parsing NewCommandLine.  The current values are returned to the
   user.
 
@@ -121,7 +122,7 @@ typedef struct {
   @param[out] OldStdErr                  Pointer to old StdErr.
   @param[out] SystemTableInfo            Pointer to old system table information.
 
-  @retval   EFI_SUCCESS                 Operation was sucessful, Argv and Argc are valid.
+  @retval   EFI_SUCCESS                 Operation was successful, Argv and Argc are valid.
   @retval   EFI_OUT_OF_RESOURCES        A memory allocation failed.
 **/
 EFI_STATUS
@@ -135,7 +136,7 @@ UpdateStdInStdOutStdErr(
   );
 
 /**
-  Funcion will replace the current StdIn and StdOut in the ShellParameters protocol
+  Function will replace the current StdIn and StdOut in the ShellParameters protocol
   structure with StdIn and StdOut.  The current values are de-allocated.
 
   @param[in, out] ShellParameters      Pointer to parameter structure to modify.
@@ -166,7 +167,8 @@ RestoreStdInStdOutStdErr (
   @param[in, out] Argv            pointer to array of strings; one for each parameter
   @param[in, out] Argc            pointer to number of strings in Argv array
 
-  @return EFI_SUCCESS           the operation was sucessful
+  @return EFI_SUCCESS           the operation was successful
+  @return EFI_INVALID_PARAMETER some parameters are invalid
   @return EFI_OUT_OF_RESOURCES  a memory allocation failed.
 **/
 EFI_STATUS
@@ -188,13 +190,13 @@ ParseCommandLineToArgs(
   function.
 
   @param[in, out] Walker          pointer to string of command line.  Adjusted to
-                                  reminaing command line on return
+                                  remaining command line on return
   @param[in, out] TempParameter   pointer to string of command line item extracted.
   @param[in]      Length          Length of (*TempParameter) in bytes
   @param[in]      StripQuotation  if TRUE then strip the quotation marks surrounding
                                   the parameters.
 
-  @return   EFI_INALID_PARAMETER  A required parameter was NULL or pointed to a NULL or empty string.
+  @return   EFI_INVALID_PARAMETER A required parameter was NULL or pointed to a NULL or empty string.
   @return   EFI_NOT_FOUND         A closing " could not be found on the specified string
 **/
 EFI_STATUS
