@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2009-2022 Oracle and/or its affiliates.
+ * Copyright (C) 2009-2023 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -38,6 +38,7 @@
 #include "QIToolButton.h"
 #include "UICloudNetworkingStuff.h"
 #include "UIEmptyFilePathSelector.h"
+#include "UIExtraDataManager.h"
 #include "UIIconPool.h"
 #include "UINotificationCenter.h"
 #include "UIVirtualBoxEventHandler.h"
@@ -194,7 +195,12 @@ void UIWizardImportAppSource::refreshProfileCombo(QIComboBox *pCombo,
         /* Clear combo initially: */
         pCombo->clear();
 
+        /* Acquire restricted accounts: */
+        const QStringList restrictedProfiles = gEDataManager->cloudProfileManagerRestrictions();
+
         /* Iterate through existing profile names: */
+        QStringList allowedProfileNames;
+        QStringList restrictedProfileNames;
         foreach (const CCloudProfile &comProfile, listCloudProfiles(comProvider, pCenter))
         {
             /* Skip if we have nothing to populate (wtf happened?): */
@@ -205,9 +211,34 @@ void UIWizardImportAppSource::refreshProfileCombo(QIComboBox *pCombo,
             if (!cloudProfileName(comProfile, strCurrentProfileName, pCenter))
                 continue;
 
+            /* Compose full profile name: */
+            const QString strFullProfileName = QString("/%1/%2").arg(strSource).arg(strCurrentProfileName);
+            /* Append to appropriate list: */
+            if (restrictedProfiles.contains(strFullProfileName))
+                restrictedProfileNames.append(strCurrentProfileName);
+            else
+                allowedProfileNames.append(strCurrentProfileName);
+        }
+
+        /* Add allowed items: */
+        foreach (const QString &strAllowedProfileName, allowedProfileNames)
+        {
             /* Compose item, fill it's data: */
-            pCombo->addItem(strCurrentProfileName);
-            pCombo->setItemData(pCombo->count() - 1, strCurrentProfileName, ProfileData_Name);
+            pCombo->addItem(strAllowedProfileName);
+            pCombo->setItemData(pCombo->count() - 1, strAllowedProfileName, ProfileData_Name);
+            QFont fnt = pCombo->font();
+            fnt.setBold(true);
+            pCombo->setItemData(pCombo->count() - 1, fnt, Qt::FontRole);
+        }
+        /* Add restricted items: */
+        foreach (const QString &strRestrictedProfileName, restrictedProfileNames)
+        {
+            /* Compose item, fill it's data: */
+            pCombo->addItem(strRestrictedProfileName);
+            pCombo->setItemData(pCombo->count() - 1, strRestrictedProfileName, ProfileData_Name);
+            QBrush brsh;
+            brsh.setColor(Qt::gray);
+            pCombo->setItemData(pCombo->count() - 1, brsh, Qt::ForegroundRole);
         }
 
         /* Set previous/default item if possible: */
