@@ -242,9 +242,6 @@
 #           undef X86_CR4_VMXE
 #       endif
 #   endif
-#   if (RTLNX_VER_MIN(5,18,0) || RTLNX_RHEL_RANGE(9,3, 9,99)) && !defined(__NO_FORTIFY) && defined(__OPTIMIZE__) && defined(CONFIG_FORTIFY_SOURCE)
-#    define SUPDRV_UNFORTIFIED_MEMCPY __underlying_memcpy
-#   endif
 #   define SUPR0_EXPORT_SYMBOL(a_Name) EXPORT_SYMBOL(a_Name)
 
 #elif defined(RT_OS_DARWIN)
@@ -376,16 +373,6 @@
 # define SUPDRV_USE_TSC_DELTA_THREAD
 #endif
 
-/** @def SUPDRV_UNFORTIFIED_MEMCPY
- * Use when copying to variable length structures, it prevents a fortified
- * memcpy (linux 5.18+) from complaining about "field-spanning writes".
- *
- * @see @ticketref{21410}, @bugref{10209}
- */
-#if !defined(SUPDRV_UNFORTIFIED_MEMCPY) || defined(DOXYGEN_RUNNING) /* (Already defined above if fortified.) */
-# define SUPDRV_UNFORTIFIED_MEMCPY memcpy
-#endif
-
 
 /*********************************************************************************************************************************
 *   Structures and Typedefs                                                                                                      *
