@@ -3,39 +3,51 @@
  */
 
 /*
- * Copyright (C) 2006-2011 Oracle Corporation
+ * Copyright (C) 2006-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only
  */
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #define LOG_GROUP LOG_GROUP_MISC
 #define LOG_ENABLED
 #include <VBox/shflsvc.h>
 #include <VBox/log.h>
-#include <iprt/alloc.h>
 #include <iprt/assert.h>
+#include <iprt/err.h>
 #include <iprt/file.h>
 #include <iprt/fs.h>
 #include <iprt/dir.h>
 #include <iprt/initterm.h>
+#include <iprt/mem.h>
 #include <iprt/path.h>
 #include <iprt/string.h>
 #include <iprt/uni.h>
 #include <stdio.h>
 
 
-/*******************************************************************************
-*   Defined Constants And Macros                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Defined Constants And Macros                                                                                                 *
+*********************************************************************************************************************************/
 /* Override slash for non-windows hosts. */
 #undef RTPATH_DELIMITER
 #define RTPATH_DELIMITER       '\\'
@@ -47,65 +59,66 @@
 #define RTDirReadEx         rtDirReadEx
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 static int iDirList = 0;
 static int iDirFile = 0;
 
-static const char *pszDirList[] =
+static const char *g_apszDirs[] =
 {
-"c:",
-"c:\\test dir",
-"c:\\test dir\\SUBDIR",
+    "c:",
+    "c:\\test dir",
+    "c:\\test dir\\SUBDIR",
 };
 
-static const char *pszDirListC[] =
+static const char *g_apszDirsC[] =
 {
-".",
-"..",
-"test dir"
+    ".",
+    "..",
+    "test dir"
 };
 
-static const char *pszDirListTestdir[] =
+static const char *g_apszTestdirEntries[] =
 {
-".",
-"..",
-"SUBDIR",
-"a.bat",
-"aTestJe.bat",
-"aTestje.bat",
-"b.bat",
-"c.bat",
-"d.bat",
-"e.bat",
-"f.bat",
-"g.bat",
-"h.bat",
-"x.bat",
-"z.bat",
+    ".",
+    "..",
+    "SUBDIR",
+    "a.bat",
+    "aTestJe.bat",
+    "aTestje.bat",
+    "b.bat",
+    "c.bat",
+    "d.bat",
+    "e.bat",
+    "f.bat",
+    "g.bat",
+    "h.bat",
+    "x.bat",
+    "z.bat",
 };
 
-static const char *pszDirListSUBDIR[] =
+static const char *g_apszSUBDIREntries[] =
 {
-".",
-"..",
-"a.bat",
-"aTestJe.bat",
-"aTestje.bat",
-"b.bat",
-"c.bat",
-"d.bat",
-"e.bat",
-"f.bat",
-"g.bat",
-"h.bat",
-"x.bat",
-"z.bat",
+    ".",
+    "..",
+    "a.bat",
+    "aTestJe.bat",
+    "aTestje.bat",
+    "b.bat",
+    "c.bat",
+    "d.bat",
+    "e.bat",
+    "f.bat",
+    "g.bat",
+    "h.bat",
+    "x.bat",
+    "z.bat",
 };
 
-int rtDirOpenFiltered(PRTDIR *ppDir, const char *pszPath, RTDIRFILTER enmFilter)
+int rtDirOpenFiltered(RTDIR *phDir, const char *pszPath, RTDIRFILTER enmFilter, uint32_t fFlags)
 {
+    RT_NOREF2(enmFilter, fFlags);
     if (!strcmp(pszPath, "c:\\*"))
         iDirList = 1;
     else if (!strcmp(pszPath, "c:\\test dir\\*"))
@@ -115,75 +128,77 @@ int rtDirOpenFiltered(PRTDIR *ppDir, const char *pszPath, RTDIRFILTER enmFilter)
     else
         AssertFailed();
 
-    *ppDir = (PRTDIR)1;
+    *phDir = (RTDIR)1;
     return VINF_SUCCESS;
 }
 
-int rtDirClose(PRTDIR pDir)
+int rtDirClose(RTDIR hDir)
 {
+    RT_NOREF1(hDir);
     iDirFile = 0;
     return VINF_SUCCESS;
 }
 
-int rtDirReadEx(PRTDIR pDir, PRTDIRENTRYEX pDirEntry, size_t *pcbDirEntry, RTFSOBJATTRADD enmAdditionalAttribs, uint32_t fFlags)
+int rtDirReadEx(RTDIR hDir, PRTDIRENTRYEX pDirEntry, size_t *pcbDirEntry, RTFSOBJATTRADD enmAdditionalAttribs, uint32_t fFlags)
 {
-    NOREF(fFlags);
-    switch(iDirList)
+    RT_NOREF4(hDir, pcbDirEntry, enmAdditionalAttribs, fFlags);
+    switch (iDirList)
     {
-    case 1:
-        if (iDirFile == RT_ELEMENTS(pszDirListC))
-            return VERR_NO_MORE_FILES;
-        pDirEntry->cbName = (uint16_t)strlen(pszDirListC[iDirFile]);
-        strcpy(pDirEntry->szName, pszDirListC[iDirFile++]);
-        break;
-    case 2:
-        if (iDirFile == RT_ELEMENTS(pszDirListTestdir))
-            return VERR_NO_MORE_FILES;
-        pDirEntry->cbName = (uint16_t)strlen(pszDirListTestdir[iDirFile]);
-        strcpy(pDirEntry->szName, pszDirListTestdir[iDirFile++]);
-        break;
-    case 3:
-        if (iDirFile == RT_ELEMENTS(pszDirListSUBDIR))
-            return VERR_NO_MORE_FILES;
-        pDirEntry->cbName = (uint16_t)strlen(pszDirListSUBDIR[iDirFile]);
-        strcpy(pDirEntry->szName, pszDirListSUBDIR[iDirFile++]);
-        break;
+        case 1:
+            if (iDirFile == RT_ELEMENTS(g_apszDirsC))
+                return VERR_NO_MORE_FILES;
+            pDirEntry->cbName = (uint16_t)strlen(g_apszDirsC[iDirFile]);
+            strcpy(pDirEntry->szName, g_apszDirsC[iDirFile++]);
+            break;
+        case 2:
+            if (iDirFile == RT_ELEMENTS(g_apszTestdirEntries))
+                return VERR_NO_MORE_FILES;
+            pDirEntry->cbName = (uint16_t)strlen(g_apszTestdirEntries[iDirFile]);
+            strcpy(pDirEntry->szName, g_apszTestdirEntries[iDirFile++]);
+            break;
+        case 3:
+            if (iDirFile == RT_ELEMENTS(g_apszSUBDIREntries))
+                return VERR_NO_MORE_FILES;
+            pDirEntry->cbName = (uint16_t)strlen(g_apszSUBDIREntries[iDirFile]);
+            strcpy(pDirEntry->szName, g_apszSUBDIREntries[iDirFile++]);
+            break;
     }
     return VINF_SUCCESS;
 }
 
 int rtPathQueryInfo(const char *pszPath, PRTFSOBJINFO pObjInfo, RTFSOBJATTRADD enmAdditionalAttribs)
 {
+    RT_NOREF2(pObjInfo, enmAdditionalAttribs);
     int cMax;
-    const char **ppszDirList;
 
-    /* first try pszDirList */
-    for (unsigned int i=0;i<RT_ELEMENTS(pszDirList);i++)
+    /* first try g_apszDirs */
+    for (unsigned int i=0;i<RT_ELEMENTS(g_apszDirs);i++)
     {
-        if(!strcmp(pszPath, pszDirList[i]))
+        if(!strcmp(pszPath, g_apszDirs[i]))
             return VINF_SUCCESS;
     }
 
-    switch(iDirList)
+    const char **papszDirList;
+    switch (iDirList)
     {
-    case 1:
-        cMax = RT_ELEMENTS(pszDirListC);
-        ppszDirList = pszDirListC;
-        break;
-    case 2:
-        cMax = RT_ELEMENTS(pszDirListTestdir);
-        ppszDirList = pszDirListTestdir;
-        break;
-    case 3:
-        cMax = RT_ELEMENTS(pszDirListSUBDIR);
-        ppszDirList = pszDirListSUBDIR;
-        break;
-    default:
-        return VERR_FILE_NOT_FOUND;
+        case 1:
+            cMax = RT_ELEMENTS(g_apszDirsC);
+            papszDirList = g_apszDirsC;
+            break;
+        case 2:
+            cMax = RT_ELEMENTS(g_apszTestdirEntries);
+            papszDirList = g_apszTestdirEntries;
+            break;
+        case 3:
+            cMax = RT_ELEMENTS(g_apszSUBDIREntries);
+            papszDirList = g_apszSUBDIREntries;
+            break;
+        default:
+            return VERR_FILE_NOT_FOUND;
     }
-    for (int i=0;i<cMax;i++)
+    for (int i = 0; i < cMax; i++)
     {
-        if(!strcmp(pszPath, ppszDirList[i]))
+        if (!strcmp(pszPath, papszDirList[i]))
             return VINF_SUCCESS;
     }
     return VERR_FILE_NOT_FOUND;
@@ -195,7 +210,7 @@ static int vbsfCorrectCasing(char *pszFullPath, char *pszStartComponent)
     uint32_t       cbDirEntry;
     size_t         cbComponent;
     int            rc = VERR_FILE_NOT_FOUND;
-    PRTDIR         hSearch = 0;
+    RTDIR          hSearch = NIL_RTDIR;
     char           szWildCard[4];
 
     Log2(("vbsfCorrectCasing: %s %s\n", pszFullPath, pszStartComponent));
@@ -220,7 +235,7 @@ static int vbsfCorrectCasing(char *pszFullPath, char *pszStartComponent)
     szWildCard[2] = 0;
     strcat(pDirEntry->szName, szWildCard);
 
-    rc = RTDirOpenFiltered (&hSearch, pDirEntry->szName, RTDIRFILTER_WINNT);
+    rc = RTDirOpenFiltered(&hSearch, pDirEntry->szName, RTDIRFILTER_WINNT, 0 /*fFlags*/);
     *(pszStartComponent-1) = RTPATH_DELIMITER;
     if (RT_FAILURE(rc))
         goto end;
