@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2013-2022 Oracle and/or its affiliates.
+ * Copyright (C) 2013-2023 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -570,7 +570,7 @@ EmulatedUSB::eusbCallbackEMT(EmulatedUSB *pThis, char *pszId, uint32_t iEvent, v
     RTMemFree(pszId);
     RTMemFree(pvData);
 
-    LogRelFlowFunc(("rc %Rrc\n", vrc));
+    LogRelFlowFunc(("vrc %Rrc\n", vrc));
     return vrc;
 }
 
