@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2022 Oracle and/or its affiliates.
+ * Copyright (C) 2006-2023 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -569,7 +569,7 @@ HRESULT Session::uninitialize()
     else
     {
         Log1WarningThisFunc(("UNEXPECTED uninitialization!\n"));
-        hrc = autoCaller.rc();
+        hrc = autoCaller.hrc();
     }
 
     LogFlowThisFunc(("hrc=%08X\n", hrc));
