@@ -4,28 +4,39 @@
  */
 
 /*
- * Copyright (C) 2008-2012 Oracle Corporation
+ * Copyright (C) 2008-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only
  */
 
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
-#define LOG_GROUP LOG_GROUP_MAIN
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
+#define LOG_GROUP LOG_GROUP_MAIN_HOST
 
-#include <iprt/err.h>
+#include <iprt/errcore.h>
 #include <list>
 #include <sys/ioctl.h>
-#include <net/if.h>
+#include <sys/socket.h>
+#include <linux/wireless.h>
 #include <net/if_arp.h>
 #include <net/route.h>
 #include <netinet/in.h>
@@ -35,16 +46,26 @@
 
 #include "HostNetworkInterfaceImpl.h"
 #include "netif.h"
-#include "Logging.h"
+#include "LoggingNew.h"
 
-static int getDefaultIfaceName(char *pszName)
+/**
+ * Obtain the name of the interface used for default routing.
+ *
+ * NOTE: There is a copy in Devices/Network/testcase/tstIntNet-1.cpp.
+ *
+ * @returns VBox status code.
+ *
+ * @param   pszName     The buffer where to put the name.
+ * @param   cbName      Size of of the destination buffer.
+ */
+static int getDefaultIfaceName(char *pszName, size_t cbName)
 {
     FILE *fp = fopen("/proc/net/route", "r");
     char szBuf[1024];
     char szIfName[17];
-    char szAddr[129];
-    char szGateway[129];
-    char szMask[129];
+    uint32_t uAddr;
+    uint32_t uGateway;
+    uint32_t uMask;
     int  iTmp;
     unsigned uFlags;
 
@@ -52,18 +73,17 @@ static int getDefaultIfaceName(char *pszName)
     {
         while (fgets(szBuf, sizeof(szBuf)-1, fp))
         {
-            int n = sscanf(szBuf, "%16s %128s %128s %X %d %d %d %128s %d %d %d\n",
-                           szIfName, szAddr, szGateway, &uFlags, &iTmp, &iTmp, &iTmp,
-                           szMask, &iTmp, &iTmp, &iTmp);
+            int n = sscanf(szBuf, "%16s %x %x %x %d %d %d %x %d %d %d\n",
+                           szIfName, &uAddr, &uGateway, &uFlags, &iTmp, &iTmp, &iTmp,
+                           &uMask, &iTmp, &iTmp, &iTmp);
             if (n < 10 || !(uFlags & RTF_UP))
                 continue;
 
-            if (strcmp(szAddr, "00000000") == 0 && strcmp(szMask, "00000000") == 0)
+            if (uAddr == 0 && uMask == 0)
             {
                 fclose(fp);
-                strncpy(pszName, szIfName, 16);
-                pszName[16] = 0;
-                return VINF_SUCCESS;
+                szIfName[sizeof(szIfName) - 1] = '\0';
+                return RTStrCopy(pszName, cbName, szIfName);
             }
         }
         fclose(fp);
@@ -71,14 +91,55 @@ static int getDefaultIfaceName(char *pszName)
     return VERR_INTERNAL_ERROR;
 }
 
+static uint32_t getInterfaceSpeed(const char *pszName)
+{
+    /*
+     * I wish I could do simple ioctl here, but older kernels require root
+     * privileges for any ethtool commands.
+     */
+    char szBuf[256];
+    uint32_t uSpeed = 0;
+    /* First, we try to retrieve the speed via sysfs. */
+    RTStrPrintf(szBuf, sizeof(szBuf), "/sys/class/net/%s/speed", pszName);
+    FILE *fp = fopen(szBuf, "r");
+    if (fp)
+    {
+        if (fscanf(fp, "%u", &uSpeed) != 1)
+            uSpeed = 0;
+        fclose(fp);
+    }
+    if (uSpeed == 10)
+    {
+        /* Check the cable is plugged in at all */
+        unsigned uCarrier = 0;
+        RTStrPrintf(szBuf, sizeof(szBuf), "/sys/class/net/%s/carrier", pszName);
+        fp = fopen(szBuf, "r");
+        if (fp)
+        {
+            if (fscanf(fp, "%u", &uCarrier) != 1 || uCarrier == 0)
+                uSpeed = 0;
+            fclose(fp);
+        }
+    }
+
+    if (uSpeed == 0)
+    {
+        /* Failed to get speed via sysfs, go to plan B. */
+        int vrc = NetIfAdpCtlOut(pszName, "speed", szBuf, sizeof(szBuf));
+        if (RT_SUCCESS(vrc))
+            uSpeed = RTStrToUInt32(szBuf);
+    }
+    return uSpeed;
+}
+
 static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
 {
     // Zeroing out pInfo is a bad idea as it should contain both short and long names at
     // this point. So make sure the structure is cleared by the caller if necessary!
     // memset(pInfo, 0, sizeof(*pInfo));
     struct ifreq Req;
-    memset(&Req, 0, sizeof(Req));
-    strncpy(Req.ifr_name, pszName, sizeof(Req.ifr_name) - 1);
+    RT_ZERO(Req);
+    RTStrCopy(Req.ifr_name, sizeof(Req.ifr_name), pszName);
     if (ioctl(iSocket, SIOCGIFHWADDR, &Req) >= 0)
     {
         switch (Req.ifr_hwaddr.sa_family)
@@ -94,8 +155,8 @@ static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
         RTUUID uuid;
         RTUuidClear(&uuid);
         memcpy(&uuid, Req.ifr_name, RT_MIN(sizeof(Req.ifr_name), sizeof(uuid)));
-        uuid.Gen.u8ClockSeqHiAndReserved = (uuid.Gen.u8ClockSeqHiAndReserved & 0x3f) | 0x80;
-        uuid.Gen.u16TimeHiAndVersion = (uuid.Gen.u16TimeHiAndVersion & 0x0fff) | 0x4000;
+        uuid.Gen.u8ClockSeqHiAndReserved = (uint8_t)((uuid.Gen.u8ClockSeqHiAndReserved & 0x3f) | 0x80);
+        uuid.Gen.u16TimeHiAndVersion = (uint16_t)((uuid.Gen.u16TimeHiAndVersion & 0x0fff) | 0x4000);
         memcpy(uuid.Gen.au8Node, &Req.ifr_hwaddr.sa_data, sizeof(uuid.Gen.au8Node));
         pInfo->Uuid = uuid;
 
@@ -114,6 +175,11 @@ static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
         if (ioctl(iSocket, SIOCGIFFLAGS, &Req) >= 0)
             pInfo->enmStatus = Req.ifr_flags & IFF_UP ? NETIF_S_UP : NETIF_S_DOWN;
 
+        struct iwreq WRq;
+        RT_ZERO(WRq);
+        RTStrCopy(WRq.ifr_name, sizeof(WRq.ifr_name), pszName);
+        pInfo->fWireless = ioctl(iSocket, SIOCGIWNAME, &WRq) >= 0;
+
         FILE *fp = fopen("/proc/net/if_inet6", "r");
         if (fp)
         {
@@ -122,7 +188,7 @@ static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
             char szName[30];
             for (;;)
             {
-                memset(szName, 0, sizeof(szName));
+                RT_ZERO(szName);
                 int n = fscanf(fp,
                                "%08x%08x%08x%08x"
                                " %02x %02x %02x %02x %20s\n",
@@ -143,7 +209,7 @@ static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
                     pInfo->IPv6Address.au32[1] = htonl(IPv6Address.au32[1]);
                     pInfo->IPv6Address.au32[2] = htonl(IPv6Address.au32[2]);
                     pInfo->IPv6Address.au32[3] = htonl(IPv6Address.au32[3]);
-                    ASMBitSetRange(&pInfo->IPv6NetMask, 0, uLength);
+                    RTNetPrefixToMaskIPv6(uLength, &pInfo->IPv6NetMask);
                 }
             }
             fclose(fp);
@@ -152,45 +218,10 @@ static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
          * Don't even try to get speed for non-Ethernet interfaces, it only
          * produces errors.
          */
-        pInfo->uSpeedMbits = 0;
         if (pInfo->enmMediumType == NETIF_T_ETHERNET)
-        {
-            /*
-             * I wish I could do simple ioctl here, but older kernels require root
-             * privileges for any ethtool commands.
-             */
-            char szBuf[256];
-            /* First, we try to retrieve the speed via sysfs. */
-            RTStrPrintf(szBuf, sizeof(szBuf), "/sys/class/net/%s/speed", pszName);
-            fp = fopen(szBuf, "r");
-            if (fp)
-            {
-                if (fscanf(fp, "%u", &pInfo->uSpeedMbits) != 1)
-                    pInfo->uSpeedMbits = 0;
-                fclose(fp);
-            }
-            if (pInfo->uSpeedMbits == 10)
-            {
-                /* Check the cable is plugged in at all */
-                unsigned uCarrier = 0;
-                RTStrPrintf(szBuf, sizeof(szBuf), "/sys/class/net/%s/carrier", pszName);
-                fp = fopen(szBuf, "r");
-                if (fp)
-                {
-                    if (fscanf(fp, "%u", &uCarrier) != 1 || uCarrier == 0)
-                        pInfo->uSpeedMbits = 0;
-                    fclose(fp);
-                }
-            }
-
-            if (pInfo->uSpeedMbits == 0)
-            {
-                /* Failed to get speed via sysfs, go to plan B. */
-                int rc = NetIfAdpCtlOut(pszName, "speed", szBuf, sizeof(szBuf));
-                if (RT_SUCCESS(rc))
-                    pInfo->uSpeedMbits = RTStrToUInt32(szBuf);
-            }
-        }
+            pInfo->uSpeedMbits = getInterfaceSpeed(pszName);
+        else
+            pInfo->uSpeedMbits = 0;
     }
     return VINF_SUCCESS;
 }
@@ -198,11 +229,11 @@ static int getInterfaceInfo(int iSocket, const char *pszName, PNETIFINFO pInfo)
 int NetIfList(std::list <ComObjPtr<HostNetworkInterface> > &list)
 {
     char szDefaultIface[256];
-    int rc = getDefaultIfaceName(szDefaultIface);
-    if (RT_FAILURE(rc))
+    int vrc = getDefaultIfaceName(szDefaultIface, sizeof(szDefaultIface));
+    if (RT_FAILURE(vrc))
     {
         Log(("NetIfList: Failed to find default interface.\n"));
-        szDefaultIface[0] = 0;
+        szDefaultIface[0] = '\0';
     }
     int sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock >= 0)
@@ -217,12 +248,12 @@ int NetIfList(std::list <ComObjPtr<HostNetworkInterface> > &list)
                 if (!pszEndOfName)
                     continue;
                 *pszEndOfName = 0;
-                int iFirstNonWS = strspn(buf, " ");
-                char *pszName = buf+iFirstNonWS;
+                size_t iFirstNonWS = strspn(buf, " ");
+                char *pszName = buf + iFirstNonWS;
                 NETIFINFO Info;
                 RT_ZERO(Info);
-                rc = getInterfaceInfo(sock, pszName, &Info);
-                if (RT_FAILURE(rc))
+                vrc = getInterfaceInfo(sock, pszName, &Info);
+                if (RT_FAILURE(vrc))
                     break;
                 if (Info.enmMediumType == NETIF_T_ETHERNET)
                 {
@@ -230,12 +261,12 @@ int NetIfList(std::list <ComObjPtr<HostNetworkInterface> > &list)
                     IfObj.createObject();
 
                     HostNetworkInterfaceType_T enmType;
-                    if (strncmp("vboxnet", pszName, 7))
+                    if (strncmp(pszName, RT_STR_TUPLE("vboxnet")))
                         enmType = HostNetworkInterfaceType_Bridged;
                     else
                         enmType = HostNetworkInterfaceType_HostOnly;
 
-                    if (SUCCEEDED(IfObj->init(Bstr(pszName), enmType, &Info)))
+                    if (SUCCEEDED(IfObj->init(pszName, enmType, &Info)))
                     {
                         if (strcmp(pszName, szDefaultIface) == 0)
                             list.push_front(IfObj);
@@ -250,18 +281,49 @@ int NetIfList(std::list <ComObjPtr<HostNetworkInterface> > &list)
         close(sock);
     }
     else
-        rc = VERR_INTERNAL_ERROR;
+        vrc = VERR_INTERNAL_ERROR;
 
-    return rc;
+    return vrc;
 }
 
 int NetIfGetConfigByName(PNETIFINFO pInfo)
 {
-    int rc = VINF_SUCCESS;
     int sock = socket(AF_INET, SOCK_DGRAM, 0);
     if (sock < 0)
         return VERR_NOT_IMPLEMENTED;
-    rc = getInterfaceInfo(sock, pInfo->szShortName, pInfo);
+    int vrc = getInterfaceInfo(sock, pInfo->szShortName, pInfo);
     close(sock);
-    return rc;
+    return vrc;
+}
+
+/**
+ * Retrieve the physical link speed in megabits per second. If the interface is
+ * not up or otherwise unavailable the zero speed is returned.
+ *
+ * @returns VBox status code.
+ *
+ * @param   pcszIfName  Interface name.
+ * @param   puMbits     Where to store the link speed.
+ */
+int NetIfGetLinkSpeed(const char *pcszIfName, uint32_t *puMbits)
+{
+    int sock = socket(AF_INET, SOCK_DGRAM, 0);
+    if (sock < 0)
+        return VERR_OUT_OF_RESOURCES;
+    struct ifreq Req;
+    RT_ZERO(Req);
+    RTStrCopy(Req.ifr_name, sizeof(Req.ifr_name), pcszIfName);
+    if (ioctl(sock, SIOCGIFHWADDR, &Req) >= 0)
+    {
+        if (ioctl(sock, SIOCGIFFLAGS, &Req) >= 0)
+            if (Req.ifr_flags & IFF_UP)
+            {
+                close(sock);
+                *puMbits = getInterfaceSpeed(pcszIfName);
+                return VINF_SUCCESS;
+            }
+    }
+    close(sock);
+    *puMbits = 0;
+    return VWRN_NOT_FOUND;
 }
