@@ -4,41 +4,51 @@
  */
 
 /*
- * Copyright (C) 2008-2015 Oracle Corporation
+ * Copyright (C) 2008-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
  *
  * The contents of this file may alternatively be used under the terms
  * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
+ * (CDDL), a copy of it is provided in the "COPYING.CDDL" file included
+ * in the VirtualBox distribution, in which case the provisions of the
  * CDDL are applicable instead of those of the GPL.
  *
  * You may elect to license modified versions of this file under the
  * terms and conditions of either the GPL or the CDDL or both.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
  */
 
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #include <iprt/rand.h>
 #include "internal/iprt.h"
 
 #include <iprt/mem.h>
-#include <iprt/err.h>
+#include <iprt/errcore.h>
 #include <iprt/assert.h>
 #include "internal/magics.h"
 #include "internal/rand.h"
 
 
-RTDECL(int) RTRandAdvDestroy(RTRAND hRand) RT_NO_THROW
+RTDECL(int) RTRandAdvDestroy(RTRAND hRand) RT_NO_THROW_DEF
 {
     /* Validate. */
     if (hRand == NIL_RTRAND)
@@ -53,7 +63,7 @@ RTDECL(int) RTRandAdvDestroy(RTRAND hRand) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvDestroy);
 
 
-RTDECL(int) RTRandAdvSeed(RTRAND hRand, uint64_t u64Seed) RT_NO_THROW
+RTDECL(int) RTRandAdvSeed(RTRAND hRand, uint64_t u64Seed) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -66,7 +76,7 @@ RTDECL(int) RTRandAdvSeed(RTRAND hRand, uint64_t u64Seed) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvSeed);
 
 
-RTDECL(int) RTRandAdvSaveState(RTRAND hRand, char *pszState, size_t *pcbState) RT_NO_THROW
+RTDECL(int) RTRandAdvSaveState(RTRAND hRand, char *pszState, size_t *pcbState) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -81,7 +91,7 @@ RTDECL(int) RTRandAdvSaveState(RTRAND hRand, char *pszState, size_t *pcbState) R
 RT_EXPORT_SYMBOL(RTRandAdvSaveState);
 
 
-RTDECL(int) RTRandAdvRestoreState(RTRAND hRand, char const *pszState) RT_NO_THROW
+RTDECL(int) RTRandAdvRestoreState(RTRAND hRand, char const *pszState) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -95,7 +105,7 @@ RTDECL(int) RTRandAdvRestoreState(RTRAND hRand, char const *pszState) RT_NO_THRO
 RT_EXPORT_SYMBOL(RTRandAdvRestoreState);
 
 
-RTDECL(void) RTRandAdvBytes(RTRAND hRand, void *pv, size_t cb) RT_NO_THROW
+RTDECL(void) RTRandAdvBytes(RTRAND hRand, void *pv, size_t cb) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -109,7 +119,7 @@ RTDECL(void) RTRandAdvBytes(RTRAND hRand, void *pv, size_t cb) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvBytes);
 
 
-RTDECL(int32_t) RTRandAdvS32Ex(RTRAND hRand, int32_t i32First, int32_t i32Last) RT_NO_THROW
+RTDECL(int32_t) RTRandAdvS32Ex(RTRAND hRand, int32_t i32First, int32_t i32Last) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -122,7 +132,7 @@ RTDECL(int32_t) RTRandAdvS32Ex(RTRAND hRand, int32_t i32First, int32_t i32Last)
 RT_EXPORT_SYMBOL(RTRandAdvS32Ex);
 
 
-RTDECL(int32_t) RTRandAdvS32(RTRAND hRand) RT_NO_THROW
+RTDECL(int32_t) RTRandAdvS32(RTRAND hRand) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -135,7 +145,7 @@ RTDECL(int32_t) RTRandAdvS32(RTRAND hRand) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvS32);
 
 
-RTDECL(uint32_t) RTRandAdvU32Ex(RTRAND hRand, uint32_t u32First, uint32_t u32Last) RT_NO_THROW
+RTDECL(uint32_t) RTRandAdvU32Ex(RTRAND hRand, uint32_t u32First, uint32_t u32Last) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -148,7 +158,7 @@ RTDECL(uint32_t) RTRandAdvU32Ex(RTRAND hRand, uint32_t u32First, uint32_t u32Las
 RT_EXPORT_SYMBOL(RTRandAdvU32Ex);
 
 
-RTDECL(uint32_t) RTRandAdvU32(RTRAND hRand) RT_NO_THROW
+RTDECL(uint32_t) RTRandAdvU32(RTRAND hRand) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -161,7 +171,7 @@ RTDECL(uint32_t) RTRandAdvU32(RTRAND hRand) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvU32);
 
 
-RTDECL(int64_t) RTRandAdvS64Ex(RTRAND hRand, int64_t i64First, int64_t i64Last) RT_NO_THROW
+RTDECL(int64_t) RTRandAdvS64Ex(RTRAND hRand, int64_t i64First, int64_t i64Last) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -174,7 +184,7 @@ RTDECL(int64_t) RTRandAdvS64Ex(RTRAND hRand, int64_t i64First, int64_t i64Last)
 RT_EXPORT_SYMBOL(RTRandAdvS64Ex);
 
 
-RTDECL(int64_t) RTRandAdvS64(RTRAND hRand) RT_NO_THROW
+RTDECL(int64_t) RTRandAdvS64(RTRAND hRand) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -187,7 +197,7 @@ RTDECL(int64_t) RTRandAdvS64(RTRAND hRand) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvS64);
 
 
-RTDECL(uint64_t) RTRandAdvU64Ex(RTRAND hRand, uint64_t u64First, uint64_t u64Last) RT_NO_THROW
+RTDECL(uint64_t) RTRandAdvU64Ex(RTRAND hRand, uint64_t u64First, uint64_t u64Last) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -200,7 +210,7 @@ RTDECL(uint64_t) RTRandAdvU64Ex(RTRAND hRand, uint64_t u64First, uint64_t u64Las
 RT_EXPORT_SYMBOL(RTRandAdvU64Ex);
 
 
-RTDECL(uint64_t) RTRandAdvU64(RTRAND hRand) RT_NO_THROW
+RTDECL(uint64_t) RTRandAdvU64(RTRAND hRand) RT_NO_THROW_DEF
 {
     /* Validate. */
     PRTRANDINT pThis = hRand;
@@ -213,7 +223,7 @@ RTDECL(uint64_t) RTRandAdvU64(RTRAND hRand) RT_NO_THROW
 RT_EXPORT_SYMBOL(RTRandAdvU64);
 
 
-DECLHIDDEN(DECLCALLBACK(void))  rtRandAdvSynthesizeBytesFromU32(PRTRANDINT pThis, uint8_t *pb, size_t cb)
+DECL_HIDDEN_CALLBACK(void)  rtRandAdvSynthesizeBytesFromU32(PRTRANDINT pThis, uint8_t *pb, size_t cb)
 {
     while (cb > 0)
     {
@@ -221,11 +231,11 @@ DECLHIDDEN(DECLCALLBACK(void))  rtRandAdvSynthesizeBytesFromU32(PRTRANDINT pThis
         switch (cb)
         {
             case 4:
-                pb[3] = (uint8_t)(u32 >> 24);
+                pb[3] = (uint8_t)(u32 >> 24); RT_FALL_THRU();
             case 3:
-                pb[2] = (uint8_t)(u32 >> 16);
+                pb[2] = (uint8_t)(u32 >> 16); RT_FALL_THRU();
             case 2:
-                pb[1] = (uint8_t)(u32 >> 8);
+                pb[1] = (uint8_t)(u32 >> 8);  RT_FALL_THRU();
             case 1:
                 pb[0] = (uint8_t)u32;
             return; /* done */
@@ -245,7 +255,7 @@ DECLHIDDEN(DECLCALLBACK(void))  rtRandAdvSynthesizeBytesFromU32(PRTRANDINT pThis
 }
 
 
-DECLHIDDEN(DECLCALLBACK(void))  rtRandAdvSynthesizeBytesFromU64(PRTRANDINT pThis, uint8_t *pb, size_t cb)
+DECL_HIDDEN_CALLBACK(void)  rtRandAdvSynthesizeBytesFromU64(PRTRANDINT pThis, uint8_t *pb, size_t cb)
 {
     while (cb > 0)
     {
@@ -253,19 +263,19 @@ DECLHIDDEN(DECLCALLBACK(void))  rtRandAdvSynthesizeBytesFromU64(PRTRANDINT pThis
         switch (cb)
         {
             case 8:
-                pb[7] = (uint8_t)(u64 >> 56);
+                pb[7] = (uint8_t)(u64 >> 56); RT_FALL_THRU();
             case 7:
-                pb[6] = (uint8_t)(u64 >> 48);
+                pb[6] = (uint8_t)(u64 >> 48); RT_FALL_THRU();
             case 6:
-                pb[5] = (uint8_t)(u64 >> 40);
+                pb[5] = (uint8_t)(u64 >> 40); RT_FALL_THRU();
             case 5:
-                pb[4] = (uint8_t)(u64 >> 32);
+                pb[4] = (uint8_t)(u64 >> 32); RT_FALL_THRU();
             case 4:
-                pb[3] = (uint8_t)(u64 >> 24);
+                pb[3] = (uint8_t)(u64 >> 24); RT_FALL_THRU();
             case 3:
-                pb[2] = (uint8_t)(u64 >> 16);
+                pb[2] = (uint8_t)(u64 >> 16); RT_FALL_THRU();
             case 2:
-                pb[1] = (uint8_t)(u64 >> 8);
+                pb[1] = (uint8_t)(u64 >> 8);  RT_FALL_THRU();
             case 1:
                 pb[0] = (uint8_t)u64;
             return; /* done */
@@ -289,7 +299,7 @@ DECLHIDDEN(DECLCALLBACK(void))  rtRandAdvSynthesizeBytesFromU64(PRTRANDINT pThis
 }
 
 
-DECLHIDDEN(DECLCALLBACK(uint32_t))  rtRandAdvSynthesizeU32FromBytes(PRTRANDINT pThis, uint32_t u32First, uint32_t u32Last)
+DECL_HIDDEN_CALLBACK(uint32_t)  rtRandAdvSynthesizeU32FromBytes(PRTRANDINT pThis, uint32_t u32First, uint32_t u32Last)
 {
     union
     {
@@ -323,13 +333,13 @@ DECLHIDDEN(DECLCALLBACK(uint32_t))  rtRandAdvSynthesizeU32FromBytes(PRTRANDINT p
 }
 
 
-DECLHIDDEN(DECLCALLBACK(uint32_t))  rtRandAdvSynthesizeU32FromU64(PRTRANDINT pThis, uint32_t u32First, uint32_t u32Last)
+DECL_HIDDEN_CALLBACK(uint32_t)  rtRandAdvSynthesizeU32FromU64(PRTRANDINT pThis, uint32_t u32First, uint32_t u32Last)
 {
     return (uint32_t)pThis->pfnGetU64(pThis, u32First, u32Last);
 }
 
 
-DECLHIDDEN(DECLCALLBACK(uint64_t))  rtRandAdvSynthesizeU64FromBytes(PRTRANDINT pThis, uint64_t u64First, uint64_t u64Last)
+DECL_HIDDEN_CALLBACK(uint64_t)  rtRandAdvSynthesizeU64FromBytes(PRTRANDINT pThis, uint64_t u64First, uint64_t u64Last)
 {
     union
     {
@@ -364,7 +374,7 @@ DECLHIDDEN(DECLCALLBACK(uint64_t))  rtRandAdvSynthesizeU64FromBytes(PRTRANDINT p
 }
 
 
-DECLHIDDEN(DECLCALLBACK(uint64_t))  rtRandAdvSynthesizeU64FromU32(PRTRANDINT pThis, uint64_t u64First, uint64_t u64Last)
+DECL_HIDDEN_CALLBACK(uint64_t)  rtRandAdvSynthesizeU64FromU32(PRTRANDINT pThis, uint64_t u64First, uint64_t u64Last)
 {
     uint64_t off = u64Last - u64First;
     if (off <= UINT32_MAX)
@@ -377,7 +387,7 @@ DECLHIDDEN(DECLCALLBACK(uint64_t))  rtRandAdvSynthesizeU64FromU32(PRTRANDINT pTh
 
 
 /** @copydoc RTRANDINT::pfnSeed */
-DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvStubSeed(PRTRANDINT pThis, uint64_t u64Seed)
+DECL_HIDDEN_CALLBACK(int) rtRandAdvStubSeed(PRTRANDINT pThis, uint64_t u64Seed)
 {
     NOREF(pThis);
     NOREF(u64Seed);
@@ -386,7 +396,7 @@ DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvStubSeed(PRTRANDINT pThis, uint64_t u64Se
 
 
 /** @copydoc RTRANDINT::pfnSaveState */
-DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvStubSaveState(PRTRANDINT pThis, char *pszState, size_t *pcbState)
+DECL_HIDDEN_CALLBACK(int) rtRandAdvStubSaveState(PRTRANDINT pThis, char *pszState, size_t *pcbState)
 {
     NOREF(pThis);
     NOREF(pszState);
@@ -396,7 +406,7 @@ DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvStubSaveState(PRTRANDINT pThis, char *psz
 
 
 /** @copydoc RTRANDINT::pfnRestoreState */
-DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvStubRestoreState(PRTRANDINT pThis, char const *pszState)
+DECL_HIDDEN_CALLBACK(int) rtRandAdvStubRestoreState(PRTRANDINT pThis, char const *pszState)
 {
     NOREF(pThis);
     NOREF(pszState);
@@ -405,7 +415,7 @@ DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvStubRestoreState(PRTRANDINT pThis, char c
 
 
 /** @copydoc RTRANDINT::pfnDestroy */
-DECLHIDDEN(DECLCALLBACK(int)) rtRandAdvDefaultDestroy(PRTRANDINT pThis)
+DECL_HIDDEN_CALLBACK(int) rtRandAdvDefaultDestroy(PRTRANDINT pThis)
 {
     pThis->u32Magic = ~RTRANDINT_MAGIC;
     RTMemFree(pThis);
