@@ -4,24 +4,34 @@
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
  *
  * The contents of this file may alternatively be used under the terms
  * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
+ * (CDDL), a copy of it is provided in the "COPYING.CDDL" file included
+ * in the VirtualBox distribution, in which case the provisions of the
  * CDDL are applicable instead of those of the GPL.
  *
  * You may elect to license modified versions of this file under the
  * terms and conditions of either the GPL or the CDDL or both.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
  */
 
 
@@ -169,6 +179,7 @@ RTDECL(int)  RTSemEventDestroy(RTSEMEVENT hEventSem)
     RT_ASSERT_INTS_ON();
     IPRT_DARWIN_SAVE_EFL_AC();
 
+    RTCCUINTREG const fIntSaved = ASMIntDisableFlags();
     lck_spin_lock(pThis->pSpinlock);
 
     ASMAtomicWriteU32(&pThis->u32Magic, ~RTSEMEVENT_MAGIC); /* make the handle invalid */
@@ -183,6 +194,7 @@ RTDECL(int)  RTSemEventDestroy(RTSEMEVENT hEventSem)
     }
 
     lck_spin_unlock(pThis->pSpinlock);
+    ASMSetFlags(fIntSaved);
     rtR0SemEventDarwinRelease(pThis);
 
     IPRT_DARWIN_RESTORE_EFL_AC();
@@ -198,13 +210,18 @@ RTDECL(int)  RTSemEventSignal(RTSEMEVENT hEventSem)
                     ("pThis=%p u32Magic=%#x\n", pThis, pThis->u32Magic),
                     VERR_INVALID_HANDLE);
     RT_ASSERT_PREEMPT_CPUID_VAR();
-    RT_ASSERT_INTS_ON();
+
+    /*
+     * Coming here with interrupts disabled should be okay.  The thread_wakeup_prim KPI is used
+     * by the interrupt handler IOFilterInterruptEventSource::disableInterruptOccurred() via
+     * signalWorkAvailable().  The only problem is if we have to destroy the event structure,
+     * as RTMemFree does not work with interrupts disabled (IOFree/kfree takes zone mutex).
+     */
+    //RT_ASSERT_INTS_ON(); - we may be called from interrupt context, which seems to be perfectly fine.
     IPRT_DARWIN_SAVE_EFL_AC();
 
+    RTCCUINTREG const fIntSaved = ASMIntDisableFlags();
     rtR0SemEventDarwinRetain(pThis);
-
-    /** @todo should probably disable interrupts here... update
-     *        semspinmutex-r0drv-generic.c when done. */
     lck_spin_lock(pThis->pSpinlock);
 
     /*
@@ -225,9 +242,11 @@ RTDECL(int)  RTSemEventSignal(RTSEMEVENT hEventSem)
     }
 
     lck_spin_unlock(pThis->pSpinlock);
+    ASMSetFlags(fIntSaved);
     rtR0SemEventDarwinRelease(pThis);
 
     RT_ASSERT_PREEMPT_CPUID();
+    AssertMsg((fSavedEfl & X86_EFL_IF) == (ASMGetFlags() & X86_EFL_IF), ("fSavedEfl=%#x cur=%#x\n",(uint32_t)fSavedEfl, ASMGetFlags()));
     IPRT_DARWIN_RESTORE_EFL_AC();
     return VINF_SUCCESS;
 }
@@ -255,6 +274,7 @@ static int rtR0SemEventDarwinWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, ui
     AssertReturn(RTSEMWAIT_FLAGS_ARE_VALID(fFlags), VERR_INVALID_PARAMETER);
     IPRT_DARWIN_SAVE_EFL_AC();
 
+    RTCCUINTREG const fIntSaved = ASMIntDisableFlags();
     rtR0SemEventDarwinRetain(pThis);
     lck_spin_lock(pThis->pSpinlock);
 
@@ -381,7 +401,9 @@ static int rtR0SemEventDarwinWait(PRTSEMEVENTINTERNAL pThis, uint32_t fFlags, ui
     }
 
     lck_spin_unlock(pThis->pSpinlock);
+    ASMSetFlags(fIntSaved);
     rtR0SemEventDarwinRelease(pThis);
+
     IPRT_DARWIN_RESTORE_EFL_AC();
     return rc;
 }
@@ -413,3 +435,11 @@ RTDECL(uint32_t) RTSemEventGetResolution(void)
     return (uint32_t)cNs ? (uint32_t)cNs : 0;
 }
 
+
+RTR0DECL(bool) RTSemEventIsSignalSafe(void)
+{
+    /** @todo check the code...   */
+    return false;
+}
+RT_EXPORT_SYMBOL(RTSemEventIsSignalSafe);
+
