@@ -4,24 +4,34 @@
  */
 
 /*
- * Copyright (C) 2006-2011 Oracle Corporation
+ * Copyright (C) 2006-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
  *
  * The contents of this file may alternatively be used under the terms
  * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
+ * (CDDL), a copy of it is provided in the "COPYING.CDDL" file included
+ * in the VirtualBox distribution, in which case the provisions of the
  * CDDL are applicable instead of those of the GPL.
  *
  * You may elect to license modified versions of this file under the
  * terms and conditions of either the GPL or the CDDL or both.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
  */
 
 /** @page pg_rtfileaio_linux     RTFile Async I/O - Linux Implementation Notes
@@ -45,9 +55,10 @@
  *        explanation would be nice, esp. seeing what Linus is quoted saying
  *        about it in the open man page... */
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #define LOG_GROUP RTLOGGROUP_FILE
 #include <iprt/asm.h>
 #include <iprt/mem.h>
@@ -65,9 +76,9 @@
 #include <iprt/file.h>
 
 
-/*******************************************************************************
-*   Structures and Typedefs                                                    *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Structures and Typedefs                                                                                                      *
+*********************************************************************************************************************************/
 /** The async I/O context handle */
 typedef unsigned long LNXKAIOCONTEXT;
 
@@ -111,10 +122,10 @@ typedef struct LNXKAIOIOCB
     uint32_t  u32Padding1;
 #endif
     /** How many bytes to transfer. */
-#ifdef RT_ARCH_X86
+#if ARCH_BITS == 32
     uint32_t  cbTransfer;
     uint32_t  u32Padding2;
-#elif defined(RT_ARCH_AMD64)
+#elif ARCH_BITS == 64
     uint64_t  cbTransfer;
 #else
 # error "Unknown architecture"
@@ -137,28 +148,28 @@ typedef struct LNXKAIOIOEVENT
 {
     /** The pvUser field from the iocb. */
     void         *pvUser;
-#ifdef RT_ARCH_X86
+#if ARCH_BITS == 32
     uint32_t      u32Padding0;
 #endif
     /** The LNXKAIOIOCB object this event is for. */
     PLNXKAIOIOCB *pIoCB;
-#ifdef RT_ARCH_X86
+#if ARCH_BITS == 32
     uint32_t      u32Padding1;
 #endif
     /** The result code of the operation .*/
-#ifdef RT_ARCH_X86
+#if ARCH_BITS == 32
     int32_t       rc;
     uint32_t      u32Padding2;
-#elif defined(RT_ARCH_AMD64)
+#elif ARCH_BITS == 64
     int64_t       rc;
 #else
 # error "Unknown architecture"
 #endif
     /** Secondary result code. */
-#ifdef RT_ARCH_X86
+#if ARCH_BITS == 32
     int32_t       rc2;
     uint32_t      u32Padding3;
-#elif defined(RT_ARCH_AMD64)
+#elif ARCH_BITS == 64
     int64_t       rc2;
 #else
 # error "Unknown architecture"
@@ -216,9 +227,9 @@ typedef struct RTFILEAIOREQINTERNAL
 typedef RTFILEAIOREQINTERNAL *PRTFILEAIOREQINTERNAL;
 
 
-/*******************************************************************************
-*   Defined Constants And Macros                                               *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Defined Constants And Macros                                                                                                 *
+*********************************************************************************************************************************/
 /** The max number of events to get in one call. */
 #define AIO_MAXIMUM_REQUESTS_PER_CONTEXT 64
 
@@ -230,7 +241,12 @@ DECLINLINE(int) rtFileAsyncIoLinuxCreate(unsigned cEvents, LNXKAIOCONTEXT *pAioC
 {
     int rc = syscall(__NR_io_setup, cEvents, pAioContext);
     if (RT_UNLIKELY(rc == -1))
-        return RTErrConvertFromErrno(errno);
+    {
+        if (errno == EAGAIN)
+            return VERR_FILE_AIO_INSUFFICIENT_EVENTS;
+        else
+            return RTErrConvertFromErrno(errno);
+    }
 
     return VINF_SUCCESS;
 }
@@ -444,8 +460,7 @@ RTDECL(int) RTFileAioReqCancel(RTFILEAIOREQ hReq)
          * Decrement request count because the request will never arrive at the
          * completion port.
          */
-        AssertMsg(VALID_PTR(pReqInt->pCtxInt),
-                  ("Invalid state. Request was canceled but wasn't submitted\n"));
+        AssertMsg(RT_VALID_PTR(pReqInt->pCtxInt), ("Invalid state. Request was canceled but wasn't submitted\n"));
 
         ASMAtomicDecS32(&pReqInt->pCtxInt->cRequests);
         pReqInt->Rc = VERR_FILE_AIO_CANCELED;
