@@ -4,29 +4,40 @@
  */
 
 /*
- * Copyright (C) 2008-2015 Oracle Corporation
+ * Copyright (C) 2008-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
  *
  * The contents of this file may alternatively be used under the terms
  * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
+ * (CDDL), a copy of it is provided in the "COPYING.CDDL" file included
+ * in the VirtualBox distribution, in which case the provisions of the
  * CDDL are applicable instead of those of the GPL.
  *
  * You may elect to license modified versions of this file under the
  * terms and conditions of either the GPL or the CDDL or both.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
  */
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #define LOG_GROUP RTLOGGROUP_DEFAULT
 #include <unistd.h>
 #include <stdio.h>
@@ -37,16 +48,17 @@
 #include <iprt/mp.h>
 #include <iprt/cpuset.h>
 #include <iprt/assert.h>
-#include <iprt/string.h>
-#include <iprt/alloc.h>
+#include <iprt/critsect.h>
+#include <iprt/err.h>
+#include <iprt/mem.h>
 #include <iprt/log.h>
 #include <iprt/once.h>
-#include <iprt/critsect.h>
+#include <iprt/string.h>
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 /** Initialization serializing (rtMpSolarisOnce). */
 static RTONCE       g_MpSolarisOnce = RTONCE_INITIALIZER;
 /** Critical section serializing access to kstat. */
@@ -90,28 +102,37 @@ static int rtMpSolarisGetCoreIds(void)
 {
     for (RTCPUID idCpu = 0; idCpu < g_capCpuInfo; idCpu++)
     {
-        if (kstat_read(g_pKsCtl, g_papCpuInfo[idCpu], 0) != -1)
+        /*
+         * It is possible that the number of cores don't match the maximum number
+         * of cores possible on the system. Hence check if we have a valid cpu_info
+         * object. We don't want to break out if it's NULL, the array may be sparse
+         * in theory, see @bugref{8469}.
+         */
+        if (g_papCpuInfo[idCpu])
         {
-            /* Strands/Hyperthreads share the same core ID. */
-            uint64_t u64CoreId  = rtMpSolarisGetCoreId(idCpu);
-            bool     fAddedCore = false;
-            for (RTCPUID i = 0; i < g_cCores; i++)
+            if (kstat_read(g_pKsCtl, g_papCpuInfo[idCpu], 0) != -1)
             {
-                if (g_pu64CoreIds[i] == u64CoreId)
+                /* Strands/Hyperthreads share the same core ID. */
+                uint64_t u64CoreId  = rtMpSolarisGetCoreId(idCpu);
+                bool     fAddedCore = false;
+                for (RTCPUID i = 0; i < g_cCores; i++)
                 {
-                    fAddedCore = true;
-                    break;
+                    if (g_pu64CoreIds[i] == u64CoreId)
+                    {
+                        fAddedCore = true;
+                        break;
+                    }
+                }
+
+                if (!fAddedCore)
+                {
+                    g_pu64CoreIds[g_cCores] = u64CoreId;
+                    ++g_cCores;
                 }
             }
-
-            if (!fAddedCore)
-            {
-                g_pu64CoreIds[g_cCores] = u64CoreId;
-                ++g_cCores;
-            }
+            else
+                return VERR_INTERNAL_ERROR_2;
         }
-        else
-            return VERR_INTERNAL_ERROR_2;
     }
 
     return VINF_SUCCESS;
@@ -136,46 +157,51 @@ static DECLCALLBACK(int) rtMpSolarisOnce(void *pvUser)
     if (g_pKsCtl)
     {
         g_capCpuInfo = RTMpGetCount();
-        g_papCpuInfo = (kstat_t **)RTMemAllocZ(g_capCpuInfo * sizeof(kstat_t *));
-        if (g_papCpuInfo)
+        if (RT_LIKELY(g_capCpuInfo > 0))
         {
-            g_cu64CoreIds = g_capCpuInfo;
-            g_pu64CoreIds = (uint64_t *)RTMemAllocZ(g_cu64CoreIds * sizeof(uint64_t));
-            if (g_pu64CoreIds)
+            g_papCpuInfo = (kstat_t **)RTMemAllocZ(g_capCpuInfo * sizeof(kstat_t *));
+            if (g_papCpuInfo)
             {
-                rc = RTCritSectInit(&g_MpSolarisCritSect);
-                if (RT_SUCCESS(rc))
+                g_cu64CoreIds = g_capCpuInfo;
+                g_pu64CoreIds = (uint64_t *)RTMemAllocZ(g_cu64CoreIds * sizeof(uint64_t));
+                if (g_pu64CoreIds)
                 {
-                    RTCPUID i = 0;
-                    for (kstat_t *pKsp = g_pKsCtl->kc_chain; pKsp != NULL; pKsp = pKsp->ks_next)
+                    rc = RTCritSectInit(&g_MpSolarisCritSect);
+                    if (RT_SUCCESS(rc))
                     {
-                        if (!RTStrCmp(pKsp->ks_module, "cpu_info"))
+                        RTCPUID i = 0;
+                        for (kstat_t *pKsp = g_pKsCtl->kc_chain; pKsp != NULL; pKsp = pKsp->ks_next)
                         {
-                            AssertBreak(i < g_capCpuInfo);
-                            g_papCpuInfo[i++] = pKsp;
-                            /** @todo ks_instance == cpu_id (/usr/src/uts/common/os/cpu.c)? Check this and fix it ASAP. */
+                            if (!RTStrCmp(pKsp->ks_module, "cpu_info"))
+                            {
+                                AssertBreak(i < g_capCpuInfo);
+                                g_papCpuInfo[i++] = pKsp;
+                                /** @todo ks_instance == cpu_id (/usr/src/uts/common/os/cpu.c)? Check this and fix it ASAP. */
+                            }
                         }
+
+                        rc = rtMpSolarisGetCoreIds();
+                        if (RT_SUCCESS(rc))
+                            return VINF_SUCCESS;
+                        else
+                            Log(("rtMpSolarisGetCoreIds failed. rc=%Rrc\n", rc));
                     }
 
-                    rc = rtMpSolarisGetCoreIds();
-                    if (RT_SUCCESS(rc))
-                        return VINF_SUCCESS;
-                    else
-                        Log(("rtMpSolarisGetCoreIds failed. rc=%Rrc\n", rc));
+                    RTMemFree(g_pu64CoreIds);
+                    g_pu64CoreIds = NULL;
                 }
+                else
+                    rc = VERR_NO_MEMORY;
 
-                RTMemFree(g_pu64CoreIds);
-                g_pu64CoreIds = NULL;
+                /* bail out, we failed. */
+                RTMemFree(g_papCpuInfo);
+                g_papCpuInfo = NULL;
             }
             else
                 rc = VERR_NO_MEMORY;
-
-            /* bail out, we failed. */
-            RTMemFree(g_papCpuInfo);
-            g_papCpuInfo = NULL;
         }
         else
-            rc = VERR_NO_MEMORY;
+            rc = VERR_CPU_IPE_1;
         kstat_close(g_pKsCtl);
         g_pKsCtl = NULL;
     }
