@@ -4,31 +4,42 @@
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2023 Oracle and/or its affiliates.
  *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ * This file is part of VirtualBox base platform packages, as
+ * available from https://www.virtualbox.org.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation, in version 3 of the
+ * License.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, see <https://www.gnu.org/licenses>.
  *
  * The contents of this file may alternatively be used under the terms
  * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
+ * (CDDL), a copy of it is provided in the "COPYING.CDDL" file included
+ * in the VirtualBox distribution, in which case the provisions of the
  * CDDL are applicable instead of those of the GPL.
  *
  * You may elect to license modified versions of this file under the
  * terms and conditions of either the GPL or the CDDL or both.
+ *
+ * SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
  */
 
-/*******************************************************************************
-*   Header Files                                                               *
-*******************************************************************************/
+
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
 #ifdef TRY_WIN32_CRIT
-# include <Windows.h>
+# include <iprt/win/windows.h>
 #endif
 #define RTCRITSECT_WITHOUT_REMAPPING
 #include <iprt/critsect.h>
@@ -36,7 +47,7 @@
 #include <iprt/asm.h>
 #include <iprt/assert.h>
 #include <iprt/ctype.h>
-#include <iprt/err.h>
+#include <iprt/errcore.h>
 #include <iprt/initterm.h>
 #include <iprt/getopt.h>
 #include <iprt/cpp/lock.h>
@@ -86,9 +97,9 @@ DECLINLINE(int) RTCritSectDelete(PCRITICAL_SECTION pCritSect)
 #endif /* TRY_WIN32_CRIT */
 
 
-/*******************************************************************************
-*   Structures and Typedefs                                                    *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Structures and Typedefs                                                                                                      *
+*********************************************************************************************************************************/
 /**
  * Arguments to ThreadTest1().
  */
@@ -137,9 +148,9 @@ typedef struct THREADTEST2ARGS
 } THREADTEST2ARGS, *PTHREADTEST2ARGS;
 
 
-/*******************************************************************************
-*   Global Variables                                                           *
-*******************************************************************************/
+/*********************************************************************************************************************************
+*   Global Variables                                                                                                             *
+*********************************************************************************************************************************/
 /** The test handle. */
 static RTTEST g_hTest;
 
@@ -150,6 +161,7 @@ static RTTEST g_hTest;
  */
 static DECLCALLBACK(int) ThreadTest1(RTTHREAD ThreadSelf, void *pvArgs)
 {
+    RT_NOREF1(ThreadSelf);
     THREADTEST1ARGS Args = *(PTHREADTEST1ARGS)pvArgs;
     Log2(("ThreadTest1: Start - iThread=%d ThreadSelf=%p\n", Args.iThread, ThreadSelf));
     RTMemFree(pvArgs);
@@ -244,6 +256,7 @@ static int Test1(unsigned cThreads)
  */
 static DECLCALLBACK(int) ThreadTest2(RTTHREAD ThreadSelf, void *pvArg)
 {
+    RT_NOREF1(ThreadSelf);
     PTHREADTEST2ARGS pArgs = (PTHREADTEST2ARGS)pvArg;
     Log2(("ThreadTest2: Start - iThread=%d ThreadSelf=%p\n", pArgs->iThread, ThreadSelf));
     uint64_t    u64TSStart = 0;
@@ -310,7 +323,7 @@ static DECLCALLBACK(int) ThreadTest2(RTTHREAD ThreadSelf, void *pvArg)
                 return 1;
             }
         }
-        ASMAtomicCmpXchgU32(pArgs->pu32Alone, pArgs->iThread, ~0);
+        ASMAtomicCmpXchgU32(pArgs->pu32Alone, pArgs->iThread, UINT32_MAX);
         for (u32 = 0; u32 < pArgs->cCheckLoops; u32++)
         {
             if (*pArgs->pu32Alone != pArgs->iThread)
@@ -320,7 +333,7 @@ static DECLCALLBACK(int) ThreadTest2(RTTHREAD ThreadSelf, void *pvArg)
                 return 1;
             }
         }
-        ASMAtomicXchgU32(pArgs->pu32Alone, ~0);
+        ASMAtomicXchgU32(pArgs->pu32Alone, UINT32_MAX);
 
         /*
          * Check for sequences.
@@ -374,8 +387,8 @@ static int Test2(unsigned cThreads, unsigned cIterations, unsigned cCheckLoops)
     RTSEMEVENT       EventDone;
     RTTEST_CHECK_RC_RET(g_hTest, RTSemEventCreate(&EventDone), VINF_SUCCESS, 1);
     uint32_t volatile   u32Release = 0;
-    uint32_t volatile   u32Alone = ~0;
-    uint32_t volatile   u32Prev = ~0;
+    uint32_t volatile   u32Alone = UINT32_MAX;
+    uint32_t volatile   u32Prev = UINT32_MAX;
     uint32_t volatile   cSeq = 0;
     uint32_t volatile   cReordered = 0;
     uint32_t volatile   cThreadRunning = 0;
@@ -491,7 +504,7 @@ int main(int argc, char **argv)
                 return 1;
 
             case 'V':
-                RTPrintf("$Revision: 100874 $\n");
+                RTPrintf("$Revision: 155244 $\n");
                 return 0;
 
             default:
