@@ -8,7 +8,7 @@ TestBox Script - main().
 
 __copyright__ = \
 """
-Copyright (C) 2012-2022 Oracle and/or its affiliates.
+Copyright (C) 2012-2023 Oracle and/or its affiliates.
 
 This file is part of VirtualBox base platform packages, as
 available from https://www.virtualbox.org.
@@ -37,7 +37,7 @@ terms and conditions of either the GPL or the CDDL or both.
 
 SPDX-License-Identifier: GPL-3.0-only OR CDDL-1.0
 """
-__version__ = "$Revision: 153224 $"
+__version__ = "$Revision: 162363 $"
 
 
 # Standard python imports.
@@ -714,7 +714,7 @@ class TestBoxScript(object):
             sFullName = os.path.join(self._oOptions.sScratchRoot, sName);
             try:
                 if os.path.isdir(sFullName):
-                    shutil.rmtree(sFullName, False, oRc.onErrorCallback);
+                    shutil.rmtree(sFullName, False, oRc.onErrorCallback); # pylint: disable=deprecated-argument
                 else:
                     os.remove(sFullName);
                 if os.path.exists(sFullName):
