@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2010-2022 Oracle and/or its affiliates.
+ * Copyright (C) 2010-2023 Oracle and/or its affiliates.
  *
  * This file is part of VirtualBox base platform packages, as
  * available from https://www.virtualbox.org.
@@ -206,6 +206,7 @@ DECLINLINE(bool) ScmIsCIdentifierChar(char ch)
         || ch == '_';
 }
 
+size_t ScmCalcSpacesForSrcSpan(const char *pchLine, size_t offStart, size_t offEnd, PCSCMSETTINGSBASE pSettings);
 
 /** @} */
 
@@ -236,18 +237,21 @@ typedef struct SCMRWSTATE
     int32_t             rc;
 } SCMRWSTATE;
 
+/** Rewriter result. */
+typedef enum { kScmUnmodified = 0, kScmModified, kScmMaybeModified } SCMREWRITERRES;
+
 /**
  * A rewriter.
  *
  * This works like a stream editor, reading @a pIn, modifying it and writing it
  * to @a pOut.
  *
- * @returns true if any changes were made, false if not.
+ * @returns kScmUnmodified, kScmModified or kScmMaybeModified.
  * @param   pIn                 The input stream.
  * @param   pOut                The output stream.
  * @param   pSettings           The settings.
  */
-typedef bool FNSCMREWRITER(PSCMRWSTATE pState, PSCMSTREAM pIn, PSCMSTREAM pOut, PCSCMSETTINGSBASE pSettings);
+typedef SCMREWRITERRES FNSCMREWRITER(PSCMRWSTATE pState, PSCMSTREAM pIn, PSCMSTREAM pOut, PCSCMSETTINGSBASE pSettings);
 /** Pointer to a rewriter method. */
 typedef FNSCMREWRITER *PFNSCMREWRITER;
 
@@ -377,6 +381,9 @@ typedef struct SCMSETTINGSBASE
     /** No rc declarations allowed, only hrc or vrc depending on the result type. */
     bool            fOnlyHrcVrcInsteadOfRc;
 
+    /** Whether to standarize kmk makefiles. */
+    bool            fStandarizeKmk;
+
     /** Update the copyright year. */
     bool            fUpdateCopyrightYear;
     /** Only external copyright holders. */
@@ -476,8 +483,9 @@ typedef SCMSETTINGS const *PCSCMSETTINGS;
 
 void ScmVerboseBanner(PSCMRWSTATE pState, int iLevel);
 void ScmVerbose(PSCMRWSTATE pState, int iLevel, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(3, 4);
-bool ScmError(PSCMRWSTATE pState, int rc, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(3, 4);
+SCMREWRITERRES ScmError(PSCMRWSTATE pState, int rc, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(3, 4);
 bool ScmFixManually(PSCMRWSTATE pState, const char *pszFormat, ...) RT_IPRT_FORMAT_ATTR(2, 3);
+bool ScmFixManuallyV(PSCMRWSTATE pState, const char *pszFormat, va_list va) RT_IPRT_FORMAT_ATTR(2, 0);
 
 extern const char g_szTabSpaces[16+1];
 extern const char g_szAsterisks[255+1];
