@@ -58,6 +58,11 @@
 #include "prproces.h"
 #include "pratom.h"
 
+#ifdef VBOX
+# include <iprt/critsect.h>
+# define VBOX_WITH_IPCCLIENT_RW_CS
+#endif
+
 /* ------------------------------------------------------------------------- */
 
 #define IPC_REQUEST_TIMEOUT PR_SecondsToInterval(30)
@@ -146,10 +151,15 @@ public:
 
   ~ipcClientState()
   {
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
     if (monitor)
       nsAutoMonitor::DestroyMonitor(monitor);
+#else
+    RTCritSectRwDelete(&critSect);
+#endif
   }
 
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
   //
   // the monitor protects the targetMap and the connected and shutdown flags.
   //
@@ -159,6 +169,9 @@ public:
   //       wrapper for PRLock.
   //
   PRMonitor    *monitor;
+#else  /* VBOX_WITH_IPCCLIENT_RW_CS */
+  RTCRITSECTRW  critSect;
+#endif /* VBOX_WITH_IPCCLIENT_RW_CS */
   ipcTargetMap  targetMap;
   PRBool        connected;
   PRBool        shutdown;
@@ -171,11 +184,20 @@ public:
 private:
 
   ipcClientState()
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
     : monitor(nsAutoMonitor::NewMonitor("ipcClientState"))
     , connected(PR_FALSE)
+#else
+    : connected(PR_FALSE)
+#endif
     , shutdown(PR_FALSE)
     , selfID(0)
-  {}
+  {
+#ifdef VBOX_WITH_IPCCLIENT_RW_CS
+    /* Not employing the lock validator here to keep performance up in debug builds. */
+    RTCritSectRwInitEx(&critSect, RTCRITSECT_FLAGS_NO_LOCK_VAL, NIL_RTLOCKVALCLASS, RTLOCKVAL_SUB_CLASS_NONE, NULL);
+#endif
+  }
 };
 
 ipcClientState *
@@ -185,7 +207,11 @@ ipcClientState::Create()
   if (!cs)
     return NULL;
 
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
   if (!cs->monitor || !cs->targetMap.Init())
+#else
+  if (!RTCritSectRwIsInitialized(&cs->critSect) || !cs->targetMap.Init())
+#endif
   {
     delete cs;
     return NULL;
@@ -201,22 +227,42 @@ static ipcClientState *gClientState;
 static PRBool
 GetTarget(const nsID &aTarget, ipcTargetData **td)
 {
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
   nsAutoMonitor mon(gClientState->monitor);
   return gClientState->targetMap.Get(nsIDHashKey(&aTarget).GetKey(), td);
+#else
+  RTCritSectRwEnterShared(&gClientState->critSect);
+  PRBool fRc = gClientState->targetMap.Get(nsIDHashKey(&aTarget).GetKey(), td);
+  RTCritSectRwLeaveShared(&gClientState->critSect);
+  return fRc;
+#endif
 }
 
 static PRBool
 PutTarget(const nsID &aTarget, ipcTargetData *td)
 {
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
   nsAutoMonitor mon(gClientState->monitor);
   return gClientState->targetMap.Put(nsIDHashKey(&aTarget).GetKey(), td);
+#else
+  RTCritSectRwEnterExcl(&gClientState->critSect);
+  PRBool fRc = gClientState->targetMap.Put(nsIDHashKey(&aTarget).GetKey(), td);
+  RTCritSectRwLeaveExcl(&gClientState->critSect);
+  return fRc;
+#endif
 }
 
 static void
 DelTarget(const nsID &aTarget)
 {
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
   nsAutoMonitor mon(gClientState->monitor);
   gClientState->targetMap.Remove(nsIDHashKey(&aTarget).GetKey());
+#else
+  RTCritSectRwEnterExcl(&gClientState->critSect);
+  gClientState->targetMap.Remove(nsIDHashKey(&aTarget).GetKey());
+  RTCritSectRwLeaveExcl(&gClientState->critSect);
+#endif
 }
 
 /* ------------------------------------------------------------------------- */
@@ -748,12 +794,18 @@ TryConnect()
   if (NS_FAILED(rv))
     return rv;
 
-  ipcMessage *msg;
+  ipcMessage *msg = NULL;
 
   // send CLIENT_HELLO and wait for CLIENT_ID response...
   rv = MakeIPCMRequest(new ipcmMessageClientHello(), &msg);
   if (NS_FAILED(rv))
+  {
+#ifdef VBOX  /* MakeIPCMRequest may return a failure (e.g. NS_ERROR_CALL_FAILED) and a response msg. */
+    if (msg)
+      delete msg;
+#endif
     return rv;
+  }
 
   if (IPCM_GetType(msg) == IPCM_MSG_ACK_CLIENT_ID)
     gClientState->selfID = ipcMessageCast<ipcmMessageClientID>(msg)->ClientID();
@@ -804,9 +856,18 @@ IPC_Shutdown()
       // first, set the shutdown flag and unblock any calls to WaitTarget.
       // all targets but IPCM will not be able to use WaitTarget any more.
 
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
       nsAutoMonitor mon(gClientState->monitor);
+#else
+      RTCritSectRwEnterExcl(&gClientState->critSect);
+#endif
+
       gClientState->shutdown = PR_TRUE;
       gClientState->targetMap.EnumerateRead(EnumerateTargetMapAndNotify, nsnull);
+
+#ifdef VBOX_WITH_IPCCLIENT_RW_CS
+      RTCritSectRwLeaveExcl(&gClientState->critSect);
+#endif
     }
 
     // inform all client observers that we're being shutdown to let interested
@@ -1088,10 +1149,6 @@ IPC_WaitMessage(PRUint32             aSenderID,
   if (NS_FAILED(rv))
     return rv;
 
-  // if the requested sender has died while waiting, return an error
-  if (data.senderDead)
-    return NS_ERROR_ABORT; // XXX better error code?
-
   // if the selector has accepted some message, then we pass it to aConsumer
   // for safe processing.  The IPC susbsystem is quite stable here (i.e. we're
   // not inside any of the monitors, and the message has been already removed
@@ -1106,6 +1163,10 @@ IPC_WaitMessage(PRUint32             aSenderID,
 
   delete msg;
 
+  // if the requested sender has died while waiting, return an error
+  if (data.senderDead)
+    return NS_ERROR_ABORT; // XXX better error code?
+
   return NS_OK;
 }
 
@@ -1169,11 +1230,17 @@ IPC_ResolveClientName(const char *aName, PRUint32 *aClientID)
 {
   NS_ENSURE_TRUE(gClientState, NS_ERROR_NOT_INITIALIZED);
 
-  ipcMessage *msg;
+  ipcMessage *msg = NULL;
 
   nsresult rv = MakeIPCMRequest(new ipcmMessageQueryClientByName(aName), &msg);
   if (NS_FAILED(rv))
+  {
+#ifdef VBOX  /* MakeIPCMRequest may return a failure (e.g. NS_ERROR_CALL_FAILED) and a response msg. */
+    if (msg)
+      delete msg;
+#endif
     return rv;
+  }
 
   if (IPCM_GetType(msg) == IPCM_MSG_ACK_CLIENT_ID)
     *aClientID = ipcMessageCast<ipcmMessageClientID>(msg)->ClientID();
@@ -1253,7 +1320,7 @@ IPC_SpawnDaemon(const char *path)
   PR_Close(writable);
   writable = nsnull;
 
-  if ((PR_Read(readable, &c, 1) != 1) && (c != IPC_STARTUP_PIPE_MAGIC))
+  if ((PR_Read(readable, &c, 1) != 1) || (c != IPC_STARTUP_PIPE_MAGIC))
     goto end;
 
   rv = NS_OK;
@@ -1289,9 +1356,18 @@ IPC_OnConnectionEnd(nsresult error)
   // now, go through the target map, and tickle each monitor.  that should
   // unblock any calls to WaitTarget.
 
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
   nsAutoMonitor mon(gClientState->monitor);
+#else
+  RTCritSectRwEnterExcl(&gClientState->critSect);
+#endif
+
   gClientState->connected = PR_FALSE;
   gClientState->targetMap.EnumerateRead(EnumerateTargetMapAndNotify, nsnull);
+
+#ifdef VBOX_WITH_IPCCLIENT_RW_CS
+  RTCritSectRwLeaveExcl(&gClientState->critSect);
+#endif
 }
 
 /* ------------------------------------------------------------------------- */
@@ -1309,6 +1385,7 @@ PlaceOnPendingQ(const nsID &target, ipcTargetData *td, ipcMessage *msg)
   td->pendingQ.Append(msg);
 
 #ifdef IPC_LOGGING
+  if (IPC_LOG_ENABLED())
   {
     char *targetStr = target.ToString();
     LOG(("placed message on pending queue for target %s and notifying all...\n", targetStr));
@@ -1391,9 +1468,17 @@ IPC_OnMessageAvailable(ipcMessage *msg)
         // pending event queue.  that unblocks all WaitTarget calls (on all
         // targets) giving them an opportuninty to finish wait cycle because of
         // the peer client death, when appropriate.
+#ifndef VBOX_WITH_IPCCLIENT_RW_CS
         nsAutoMonitor mon(gClientState->monitor);
+#else
+        RTCritSectRwEnterShared(&gClientState->critSect);
+#endif
+
         gClientState->targetMap.EnumerateRead(EnumerateTargetMapAndPlaceMsg, msg);
 
+#ifdef VBOX_WITH_IPCCLIENT_RW_CS
+        RTCritSectRwLeaveShared(&gClientState->critSect);
+#endif
         delete msg;
 
         return;
@@ -1413,5 +1498,8 @@ IPC_OnMessageAvailable(ipcMessage *msg)
   else
   {
     NS_WARNING("message target is undefined");
+#ifdef VBOX
+    delete msg;
+#endif
   }
 }
